from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Security.Authentication.OnlineId
import win32more.Windows.System
import win32more.Windows.Win32.System.WinRT
class CredentialPromptType(Enum, Int32):
    PromptIfNeeded = 0
    RetypeCredentials = 1
    DoNotPrompt = 2
class IOnlineIdAuthenticator(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Security.Authentication.OnlineId.IOnlineIdAuthenticator'
    _iid_ = Guid('{a003f58a-29ab-4817-b884-d7516dad18b9}')
    @winrt_commethod(6)
    def AuthenticateUserAsync(self, request: win32more.Windows.Security.Authentication.OnlineId.OnlineIdServiceTicketRequest) -> win32more.Windows.Security.Authentication.OnlineId.UserAuthenticationOperation: ...
    @winrt_commethod(7)
    def AuthenticateUserAsyncAdvanced(self, requests: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Security.Authentication.OnlineId.OnlineIdServiceTicketRequest], credentialPromptType: win32more.Windows.Security.Authentication.OnlineId.CredentialPromptType) -> win32more.Windows.Security.Authentication.OnlineId.UserAuthenticationOperation: ...
    @winrt_commethod(8)
    def SignOutUserAsync(self) -> win32more.Windows.Security.Authentication.OnlineId.SignOutUserOperation: ...
    @winrt_commethod(9)
    def put_ApplicationId(self, value: Guid) -> Void: ...
    @winrt_commethod(10)
    def get_ApplicationId(self) -> Guid: ...
    @winrt_commethod(11)
    def get_CanSignOut(self) -> Boolean: ...
    @winrt_commethod(12)
    def get_AuthenticatedSafeCustomerId(self) -> WinRT_String: ...
    ApplicationId = property(get_ApplicationId, put_ApplicationId)
    AuthenticatedSafeCustomerId = property(get_AuthenticatedSafeCustomerId, None)
    CanSignOut = property(get_CanSignOut, None)
class IOnlineIdServiceTicket(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Security.Authentication.OnlineId.IOnlineIdServiceTicket'
    _iid_ = Guid('{c95c547f-d781-4a94-acb8-c59874238c26}')
    @winrt_commethod(6)
    def get_Value(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_Request(self) -> win32more.Windows.Security.Authentication.OnlineId.OnlineIdServiceTicketRequest: ...
    @winrt_commethod(8)
    def get_ErrorCode(self) -> Int32: ...
    ErrorCode = property(get_ErrorCode, None)
    Request = property(get_Request, None)
    Value = property(get_Value, None)
class IOnlineIdServiceTicketRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Security.Authentication.OnlineId.IOnlineIdServiceTicketRequest'
    _iid_ = Guid('{297445d3-fb63-4135-8909-4e354c061466}')
    @winrt_commethod(6)
    def get_Service(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_Policy(self) -> WinRT_String: ...
    Policy = property(get_Policy, None)
    Service = property(get_Service, None)
class IOnlineIdServiceTicketRequestFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Security.Authentication.OnlineId.IOnlineIdServiceTicketRequestFactory'
    _iid_ = Guid('{bebb0a08-9e73-4077-9614-08614c0bc245}')
    @winrt_commethod(6)
    def CreateOnlineIdServiceTicketRequest(self, service: WinRT_String, policy: WinRT_String) -> win32more.Windows.Security.Authentication.OnlineId.OnlineIdServiceTicketRequest: ...
    @winrt_commethod(7)
    def CreateOnlineIdServiceTicketRequestAdvanced(self, service: WinRT_String) -> win32more.Windows.Security.Authentication.OnlineId.OnlineIdServiceTicketRequest: ...
class IOnlineIdSystemAuthenticatorForUser(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Security.Authentication.OnlineId.IOnlineIdSystemAuthenticatorForUser'
    _iid_ = Guid('{5798befb-1de4-4186-a2e6-b563f86aaf44}')
    @winrt_commethod(6)
    def GetTicketAsync(self, request: win32more.Windows.Security.Authentication.OnlineId.OnlineIdServiceTicketRequest) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Security.Authentication.OnlineId.OnlineIdSystemTicketResult]: ...
    @winrt_commethod(7)
    def put_ApplicationId(self, value: Guid) -> Void: ...
    @winrt_commethod(8)
    def get_ApplicationId(self) -> Guid: ...
    @winrt_commethod(9)
    def get_User(self) -> win32more.Windows.System.User: ...
    ApplicationId = property(get_ApplicationId, put_ApplicationId)
    User = property(get_User, None)
class IOnlineIdSystemAuthenticatorStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Security.Authentication.OnlineId.IOnlineIdSystemAuthenticatorStatics'
    _iid_ = Guid('{85047792-f634-41e3-96a4-5164e902c740}')
    @winrt_commethod(6)
    def get_Default(self) -> win32more.Windows.Security.Authentication.OnlineId.OnlineIdSystemAuthenticatorForUser: ...
    @winrt_commethod(7)
    def GetForUser(self, user: win32more.Windows.System.User) -> win32more.Windows.Security.Authentication.OnlineId.OnlineIdSystemAuthenticatorForUser: ...
    Default = property(get_Default, None)
class IOnlineIdSystemIdentity(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Security.Authentication.OnlineId.IOnlineIdSystemIdentity'
    _iid_ = Guid('{743cd20d-b6ca-434d-8124-53ea12685307}')
    @winrt_commethod(6)
    def get_Ticket(self) -> win32more.Windows.Security.Authentication.OnlineId.OnlineIdServiceTicket: ...
    @winrt_commethod(7)
    def get_Id(self) -> WinRT_String: ...
    Id = property(get_Id, None)
    Ticket = property(get_Ticket, None)
class IOnlineIdSystemTicketResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Security.Authentication.OnlineId.IOnlineIdSystemTicketResult'
    _iid_ = Guid('{db0a5ff8-b098-4acd-9d13-9e640652b5b6}')
    @winrt_commethod(6)
    def get_Identity(self) -> win32more.Windows.Security.Authentication.OnlineId.OnlineIdSystemIdentity: ...
    @winrt_commethod(7)
    def get_Status(self) -> win32more.Windows.Security.Authentication.OnlineId.OnlineIdSystemTicketStatus: ...
    @winrt_commethod(8)
    def get_ExtendedError(self) -> win32more.Windows.Foundation.HResult: ...
    ExtendedError = property(get_ExtendedError, None)
    Identity = property(get_Identity, None)
    Status = property(get_Status, None)
class IUserIdentity(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Security.Authentication.OnlineId.IUserIdentity'
    _iid_ = Guid('{2146d9cd-0742-4be3-8a1c-7c7ae679aa88}')
    @winrt_commethod(6)
    def get_Tickets(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Security.Authentication.OnlineId.OnlineIdServiceTicket]: ...
    @winrt_commethod(7)
    def get_Id(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_SafeCustomerId(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def get_SignInName(self) -> WinRT_String: ...
    @winrt_commethod(10)
    def get_FirstName(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def get_LastName(self) -> WinRT_String: ...
    @winrt_commethod(12)
    def get_IsBetaAccount(self) -> Boolean: ...
    @winrt_commethod(13)
    def get_IsConfirmedPC(self) -> Boolean: ...
    FirstName = property(get_FirstName, None)
    Id = property(get_Id, None)
    IsBetaAccount = property(get_IsBetaAccount, None)
    IsConfirmedPC = property(get_IsConfirmedPC, None)
    LastName = property(get_LastName, None)
    SafeCustomerId = property(get_SafeCustomerId, None)
    SignInName = property(get_SignInName, None)
    Tickets = property(get_Tickets, None)
class OnlineIdAuthenticator(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Security.Authentication.OnlineId.IOnlineIdAuthenticator
    _classid_ = 'Windows.Security.Authentication.OnlineId.OnlineIdAuthenticator'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.Security.Authentication.OnlineId.OnlineIdAuthenticator.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.Security.Authentication.OnlineId.OnlineIdAuthenticator: ...
    @winrt_mixinmethod
    def AuthenticateUserAsync(self: win32more.Windows.Security.Authentication.OnlineId.IOnlineIdAuthenticator, request: win32more.Windows.Security.Authentication.OnlineId.OnlineIdServiceTicketRequest) -> win32more.Windows.Security.Authentication.OnlineId.UserAuthenticationOperation: ...
    @winrt_mixinmethod
    def AuthenticateUserAsyncAdvanced(self: win32more.Windows.Security.Authentication.OnlineId.IOnlineIdAuthenticator, requests: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Security.Authentication.OnlineId.OnlineIdServiceTicketRequest], credentialPromptType: win32more.Windows.Security.Authentication.OnlineId.CredentialPromptType) -> win32more.Windows.Security.Authentication.OnlineId.UserAuthenticationOperation: ...
    @winrt_mixinmethod
    def SignOutUserAsync(self: win32more.Windows.Security.Authentication.OnlineId.IOnlineIdAuthenticator) -> win32more.Windows.Security.Authentication.OnlineId.SignOutUserOperation: ...
    @winrt_mixinmethod
    def put_ApplicationId(self: win32more.Windows.Security.Authentication.OnlineId.IOnlineIdAuthenticator, value: Guid) -> Void: ...
    @winrt_mixinmethod
    def get_ApplicationId(self: win32more.Windows.Security.Authentication.OnlineId.IOnlineIdAuthenticator) -> Guid: ...
    @winrt_mixinmethod
    def get_CanSignOut(self: win32more.Windows.Security.Authentication.OnlineId.IOnlineIdAuthenticator) -> Boolean: ...
    @winrt_mixinmethod
    def get_AuthenticatedSafeCustomerId(self: win32more.Windows.Security.Authentication.OnlineId.IOnlineIdAuthenticator) -> WinRT_String: ...
    ApplicationId = property(get_ApplicationId, put_ApplicationId)
    AuthenticatedSafeCustomerId = property(get_AuthenticatedSafeCustomerId, None)
    CanSignOut = property(get_CanSignOut, None)
class OnlineIdServiceTicket(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Security.Authentication.OnlineId.IOnlineIdServiceTicket
    _classid_ = 'Windows.Security.Authentication.OnlineId.OnlineIdServiceTicket'
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Security.Authentication.OnlineId.IOnlineIdServiceTicket) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Request(self: win32more.Windows.Security.Authentication.OnlineId.IOnlineIdServiceTicket) -> win32more.Windows.Security.Authentication.OnlineId.OnlineIdServiceTicketRequest: ...
    @winrt_mixinmethod
    def get_ErrorCode(self: win32more.Windows.Security.Authentication.OnlineId.IOnlineIdServiceTicket) -> Int32: ...
    ErrorCode = property(get_ErrorCode, None)
    Request = property(get_Request, None)
    Value = property(get_Value, None)
class OnlineIdServiceTicketRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Security.Authentication.OnlineId.IOnlineIdServiceTicketRequest
    _classid_ = 'Windows.Security.Authentication.OnlineId.OnlineIdServiceTicketRequest'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Windows.Security.Authentication.OnlineId.OnlineIdServiceTicketRequest.CreateOnlineIdServiceTicketRequestAdvanced(*args))
        elif len(args) == 2:
            super().__init__(move=win32more.Windows.Security.Authentication.OnlineId.OnlineIdServiceTicketRequest.CreateOnlineIdServiceTicketRequest(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateOnlineIdServiceTicketRequestAdvanced(cls: win32more.Windows.Security.Authentication.OnlineId.IOnlineIdServiceTicketRequestFactory, service: WinRT_String) -> win32more.Windows.Security.Authentication.OnlineId.OnlineIdServiceTicketRequest: ...
    @winrt_factorymethod
    def CreateOnlineIdServiceTicketRequest(cls: win32more.Windows.Security.Authentication.OnlineId.IOnlineIdServiceTicketRequestFactory, service: WinRT_String, policy: WinRT_String) -> win32more.Windows.Security.Authentication.OnlineId.OnlineIdServiceTicketRequest: ...
    @winrt_mixinmethod
    def get_Service(self: win32more.Windows.Security.Authentication.OnlineId.IOnlineIdServiceTicketRequest) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Policy(self: win32more.Windows.Security.Authentication.OnlineId.IOnlineIdServiceTicketRequest) -> WinRT_String: ...
    Policy = property(get_Policy, None)
    Service = property(get_Service, None)
class _OnlineIdSystemAuthenticator_Meta_(ComPtr.__class__):
    pass
class OnlineIdSystemAuthenticator(ComPtr, metaclass=_OnlineIdSystemAuthenticator_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Security.Authentication.OnlineId.OnlineIdSystemAuthenticator'
    @winrt_classmethod
    def get_Default(cls: win32more.Windows.Security.Authentication.OnlineId.IOnlineIdSystemAuthenticatorStatics) -> win32more.Windows.Security.Authentication.OnlineId.OnlineIdSystemAuthenticatorForUser: ...
    @winrt_classmethod
    def GetForUser(cls: win32more.Windows.Security.Authentication.OnlineId.IOnlineIdSystemAuthenticatorStatics, user: win32more.Windows.System.User) -> win32more.Windows.Security.Authentication.OnlineId.OnlineIdSystemAuthenticatorForUser: ...
    _OnlineIdSystemAuthenticator_Meta_.Default = property(get_Default, None)
class OnlineIdSystemAuthenticatorForUser(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Security.Authentication.OnlineId.IOnlineIdSystemAuthenticatorForUser
    _classid_ = 'Windows.Security.Authentication.OnlineId.OnlineIdSystemAuthenticatorForUser'
    @winrt_mixinmethod
    def GetTicketAsync(self: win32more.Windows.Security.Authentication.OnlineId.IOnlineIdSystemAuthenticatorForUser, request: win32more.Windows.Security.Authentication.OnlineId.OnlineIdServiceTicketRequest) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Security.Authentication.OnlineId.OnlineIdSystemTicketResult]: ...
    @winrt_mixinmethod
    def put_ApplicationId(self: win32more.Windows.Security.Authentication.OnlineId.IOnlineIdSystemAuthenticatorForUser, value: Guid) -> Void: ...
    @winrt_mixinmethod
    def get_ApplicationId(self: win32more.Windows.Security.Authentication.OnlineId.IOnlineIdSystemAuthenticatorForUser) -> Guid: ...
    @winrt_mixinmethod
    def get_User(self: win32more.Windows.Security.Authentication.OnlineId.IOnlineIdSystemAuthenticatorForUser) -> win32more.Windows.System.User: ...
    ApplicationId = property(get_ApplicationId, put_ApplicationId)
    User = property(get_User, None)
class OnlineIdSystemIdentity(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Security.Authentication.OnlineId.IOnlineIdSystemIdentity
    _classid_ = 'Windows.Security.Authentication.OnlineId.OnlineIdSystemIdentity'
    @winrt_mixinmethod
    def get_Ticket(self: win32more.Windows.Security.Authentication.OnlineId.IOnlineIdSystemIdentity) -> win32more.Windows.Security.Authentication.OnlineId.OnlineIdServiceTicket: ...
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.Security.Authentication.OnlineId.IOnlineIdSystemIdentity) -> WinRT_String: ...
    Id = property(get_Id, None)
    Ticket = property(get_Ticket, None)
class OnlineIdSystemTicketResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Security.Authentication.OnlineId.IOnlineIdSystemTicketResult
    _classid_ = 'Windows.Security.Authentication.OnlineId.OnlineIdSystemTicketResult'
    @winrt_mixinmethod
    def get_Identity(self: win32more.Windows.Security.Authentication.OnlineId.IOnlineIdSystemTicketResult) -> win32more.Windows.Security.Authentication.OnlineId.OnlineIdSystemIdentity: ...
    @winrt_mixinmethod
    def get_Status(self: win32more.Windows.Security.Authentication.OnlineId.IOnlineIdSystemTicketResult) -> win32more.Windows.Security.Authentication.OnlineId.OnlineIdSystemTicketStatus: ...
    @winrt_mixinmethod
    def get_ExtendedError(self: win32more.Windows.Security.Authentication.OnlineId.IOnlineIdSystemTicketResult) -> win32more.Windows.Foundation.HResult: ...
    ExtendedError = property(get_ExtendedError, None)
    Identity = property(get_Identity, None)
    Status = property(get_Status, None)
class OnlineIdSystemTicketStatus(Enum, Int32):
    Success = 0
    Error = 1
    ServiceConnectionError = 2
class SignOutUserOperation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[AwaitableProtocol]
    default_interface: win32more.Windows.Foundation.IAsyncAction
    _classid_ = 'Windows.Security.Authentication.OnlineId.SignOutUserOperation'
    @winrt_mixinmethod
    def put_Completed(self: win32more.Windows.Foundation.IAsyncAction, handler: win32more.Windows.Foundation.AsyncActionCompletedHandler) -> Void: ...
    @winrt_mixinmethod
    def get_Completed(self: win32more.Windows.Foundation.IAsyncAction) -> win32more.Windows.Foundation.AsyncActionCompletedHandler: ...
    @winrt_mixinmethod
    def GetResults(self: win32more.Windows.Foundation.IAsyncAction) -> Void: ...
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.Foundation.IAsyncInfo) -> UInt32: ...
    @winrt_mixinmethod
    def get_Status(self: win32more.Windows.Foundation.IAsyncInfo) -> win32more.Windows.Foundation.AsyncStatus: ...
    @winrt_mixinmethod
    def get_ErrorCode(self: win32more.Windows.Foundation.IAsyncInfo) -> win32more.Windows.Foundation.HResult: ...
    @winrt_mixinmethod
    def Cancel(self: win32more.Windows.Foundation.IAsyncInfo) -> Void: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IAsyncInfo) -> Void: ...
    Completed = property(get_Completed, put_Completed)
    ErrorCode = property(get_ErrorCode, None)
    Id = property(get_Id, None)
    Status = property(get_Status, None)
class UserAuthenticationOperation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[AwaitableProtocol]
    default_interface: win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Security.Authentication.OnlineId.UserIdentity]
    _classid_ = 'Windows.Security.Authentication.OnlineId.UserAuthenticationOperation'
    @winrt_mixinmethod
    def put_Completed(self: win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Security.Authentication.OnlineId.UserIdentity], handler: win32more.Windows.Foundation.AsyncOperationCompletedHandler[win32more.Windows.Security.Authentication.OnlineId.UserIdentity]) -> Void: ...
    @winrt_mixinmethod
    def get_Completed(self: win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Security.Authentication.OnlineId.UserIdentity]) -> win32more.Windows.Foundation.AsyncOperationCompletedHandler[win32more.Windows.Security.Authentication.OnlineId.UserIdentity]: ...
    @winrt_mixinmethod
    def GetResults(self: win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Security.Authentication.OnlineId.UserIdentity]) -> win32more.Windows.Security.Authentication.OnlineId.UserIdentity: ...
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.Foundation.IAsyncInfo) -> UInt32: ...
    @winrt_mixinmethod
    def get_Status(self: win32more.Windows.Foundation.IAsyncInfo) -> win32more.Windows.Foundation.AsyncStatus: ...
    @winrt_mixinmethod
    def get_ErrorCode(self: win32more.Windows.Foundation.IAsyncInfo) -> win32more.Windows.Foundation.HResult: ...
    @winrt_mixinmethod
    def Cancel(self: win32more.Windows.Foundation.IAsyncInfo) -> Void: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IAsyncInfo) -> Void: ...
    Completed = property(get_Completed, put_Completed)
    ErrorCode = property(get_ErrorCode, None)
    Id = property(get_Id, None)
    Status = property(get_Status, None)
class UserIdentity(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Security.Authentication.OnlineId.IUserIdentity
    _classid_ = 'Windows.Security.Authentication.OnlineId.UserIdentity'
    @winrt_mixinmethod
    def get_Tickets(self: win32more.Windows.Security.Authentication.OnlineId.IUserIdentity) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Security.Authentication.OnlineId.OnlineIdServiceTicket]: ...
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.Security.Authentication.OnlineId.IUserIdentity) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_SafeCustomerId(self: win32more.Windows.Security.Authentication.OnlineId.IUserIdentity) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_SignInName(self: win32more.Windows.Security.Authentication.OnlineId.IUserIdentity) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_FirstName(self: win32more.Windows.Security.Authentication.OnlineId.IUserIdentity) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_LastName(self: win32more.Windows.Security.Authentication.OnlineId.IUserIdentity) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_IsBetaAccount(self: win32more.Windows.Security.Authentication.OnlineId.IUserIdentity) -> Boolean: ...
    @winrt_mixinmethod
    def get_IsConfirmedPC(self: win32more.Windows.Security.Authentication.OnlineId.IUserIdentity) -> Boolean: ...
    FirstName = property(get_FirstName, None)
    Id = property(get_Id, None)
    IsBetaAccount = property(get_IsBetaAccount, None)
    IsConfirmedPC = property(get_IsConfirmedPC, None)
    LastName = property(get_LastName, None)
    SafeCustomerId = property(get_SafeCustomerId, None)
    SignInName = property(get_SignInName, None)
    Tickets = property(get_Tickets, None)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Devices.Scanners
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Graphics.Printing
import win32more.Windows.Storage
import win32more.Windows.Storage.Streams
import win32more.Windows.Win32.System.WinRT
class IImageScanner(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Scanners.IImageScanner'
    _iid_ = Guid('{53a88f78-5298-48a0-8da3-8087519665e0}')
    @winrt_commethod(6)
    def get_DeviceId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_DefaultScanSource(self) -> win32more.Windows.Devices.Scanners.ImageScannerScanSource: ...
    @winrt_commethod(8)
    def IsScanSourceSupported(self, value: win32more.Windows.Devices.Scanners.ImageScannerScanSource) -> Boolean: ...
    @winrt_commethod(9)
    def get_FlatbedConfiguration(self) -> win32more.Windows.Devices.Scanners.ImageScannerFlatbedConfiguration: ...
    @winrt_commethod(10)
    def get_FeederConfiguration(self) -> win32more.Windows.Devices.Scanners.ImageScannerFeederConfiguration: ...
    @winrt_commethod(11)
    def get_AutoConfiguration(self) -> win32more.Windows.Devices.Scanners.ImageScannerAutoConfiguration: ...
    @winrt_commethod(12)
    def IsPreviewSupported(self, scanSource: win32more.Windows.Devices.Scanners.ImageScannerScanSource) -> Boolean: ...
    @winrt_commethod(13)
    def ScanPreviewToStreamAsync(self, scanSource: win32more.Windows.Devices.Scanners.ImageScannerScanSource, targetStream: win32more.Windows.Storage.Streams.IRandomAccessStream) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.Scanners.ImageScannerPreviewResult]: ...
    @winrt_commethod(14)
    def ScanFilesToFolderAsync(self, scanSource: win32more.Windows.Devices.Scanners.ImageScannerScanSource, storageFolder: win32more.Windows.Storage.StorageFolder) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Windows.Devices.Scanners.ImageScannerScanResult, UInt32]: ...
    AutoConfiguration = property(get_AutoConfiguration, None)
    DefaultScanSource = property(get_DefaultScanSource, None)
    DeviceId = property(get_DeviceId, None)
    FeederConfiguration = property(get_FeederConfiguration, None)
    FlatbedConfiguration = property(get_FlatbedConfiguration, None)
class IImageScannerFeederConfiguration(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Scanners.IImageScannerFeederConfiguration'
    _iid_ = Guid('{74bdacee-fa97-4c17-8280-40e39c6dcc67}')
    @winrt_commethod(6)
    def get_CanAutoDetectPageSize(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_AutoDetectPageSize(self) -> Boolean: ...
    @winrt_commethod(8)
    def put_AutoDetectPageSize(self, value: Boolean) -> Void: ...
    @winrt_commethod(9)
    def get_PageSize(self) -> win32more.Windows.Graphics.Printing.PrintMediaSize: ...
    @winrt_commethod(10)
    def put_PageSize(self, value: win32more.Windows.Graphics.Printing.PrintMediaSize) -> Void: ...
    @winrt_commethod(11)
    def get_PageOrientation(self) -> win32more.Windows.Graphics.Printing.PrintOrientation: ...
    @winrt_commethod(12)
    def put_PageOrientation(self, value: win32more.Windows.Graphics.Printing.PrintOrientation) -> Void: ...
    @winrt_commethod(13)
    def get_PageSizeDimensions(self) -> win32more.Windows.Foundation.Size: ...
    @winrt_commethod(14)
    def IsPageSizeSupported(self, pageSize: win32more.Windows.Graphics.Printing.PrintMediaSize, pageOrientation: win32more.Windows.Graphics.Printing.PrintOrientation) -> Boolean: ...
    @winrt_commethod(15)
    def get_MaxNumberOfPages(self) -> UInt32: ...
    @winrt_commethod(16)
    def put_MaxNumberOfPages(self, value: UInt32) -> Void: ...
    @winrt_commethod(17)
    def get_CanScanDuplex(self) -> Boolean: ...
    @winrt_commethod(18)
    def get_Duplex(self) -> Boolean: ...
    @winrt_commethod(19)
    def put_Duplex(self, value: Boolean) -> Void: ...
    @winrt_commethod(20)
    def get_CanScanAhead(self) -> Boolean: ...
    @winrt_commethod(21)
    def get_ScanAhead(self) -> Boolean: ...
    @winrt_commethod(22)
    def put_ScanAhead(self, value: Boolean) -> Void: ...
    AutoDetectPageSize = property(get_AutoDetectPageSize, put_AutoDetectPageSize)
    CanAutoDetectPageSize = property(get_CanAutoDetectPageSize, None)
    CanScanAhead = property(get_CanScanAhead, None)
    CanScanDuplex = property(get_CanScanDuplex, None)
    Duplex = property(get_Duplex, put_Duplex)
    MaxNumberOfPages = property(get_MaxNumberOfPages, put_MaxNumberOfPages)
    PageOrientation = property(get_PageOrientation, put_PageOrientation)
    PageSize = property(get_PageSize, put_PageSize)
    PageSizeDimensions = property(get_PageSizeDimensions, None)
    ScanAhead = property(get_ScanAhead, put_ScanAhead)
class IImageScannerFormatConfiguration(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Scanners.IImageScannerFormatConfiguration'
    _iid_ = Guid('{ae275d11-dadf-4010-bf10-cca5c83dcbb0}')
    @winrt_commethod(6)
    def get_DefaultFormat(self) -> win32more.Windows.Devices.Scanners.ImageScannerFormat: ...
    @winrt_commethod(7)
    def get_Format(self) -> win32more.Windows.Devices.Scanners.ImageScannerFormat: ...
    @winrt_commethod(8)
    def put_Format(self, value: win32more.Windows.Devices.Scanners.ImageScannerFormat) -> Void: ...
    @winrt_commethod(9)
    def IsFormatSupported(self, value: win32more.Windows.Devices.Scanners.ImageScannerFormat) -> Boolean: ...
    DefaultFormat = property(get_DefaultFormat, None)
    Format = property(get_Format, put_Format)
class IImageScannerPreviewResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Scanners.IImageScannerPreviewResult'
    _iid_ = Guid('{08b7fe8e-8891-441d-be9c-176fa109c8bb}')
    @winrt_commethod(6)
    def get_Succeeded(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_Format(self) -> win32more.Windows.Devices.Scanners.ImageScannerFormat: ...
    Format = property(get_Format, None)
    Succeeded = property(get_Succeeded, None)
class IImageScannerScanResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Scanners.IImageScannerScanResult'
    _iid_ = Guid('{c91624cd-9037-4e48-84c1-ac0975076bc5}')
    @winrt_commethod(6)
    def get_ScannedFiles(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Storage.StorageFile]: ...
    ScannedFiles = property(get_ScannedFiles, None)
class IImageScannerSourceConfiguration(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Scanners.IImageScannerSourceConfiguration'
    _iid_ = Guid('{bfb50055-0b44-4c82-9e89-205f9c234e59}')
    @winrt_commethod(6)
    def get_MinScanArea(self) -> win32more.Windows.Foundation.Size: ...
    @winrt_commethod(7)
    def get_MaxScanArea(self) -> win32more.Windows.Foundation.Size: ...
    @winrt_commethod(8)
    def get_SelectedScanRegion(self) -> win32more.Windows.Foundation.Rect: ...
    @winrt_commethod(9)
    def put_SelectedScanRegion(self, value: win32more.Windows.Foundation.Rect) -> Void: ...
    @winrt_commethod(10)
    def get_AutoCroppingMode(self) -> win32more.Windows.Devices.Scanners.ImageScannerAutoCroppingMode: ...
    @winrt_commethod(11)
    def put_AutoCroppingMode(self, value: win32more.Windows.Devices.Scanners.ImageScannerAutoCroppingMode) -> Void: ...
    @winrt_commethod(12)
    def IsAutoCroppingModeSupported(self, value: win32more.Windows.Devices.Scanners.ImageScannerAutoCroppingMode) -> Boolean: ...
    @winrt_commethod(13)
    def get_MinResolution(self) -> win32more.Windows.Devices.Scanners.ImageScannerResolution: ...
    @winrt_commethod(14)
    def get_MaxResolution(self) -> win32more.Windows.Devices.Scanners.ImageScannerResolution: ...
    @winrt_commethod(15)
    def get_OpticalResolution(self) -> win32more.Windows.Devices.Scanners.ImageScannerResolution: ...
    @winrt_commethod(16)
    def get_DesiredResolution(self) -> win32more.Windows.Devices.Scanners.ImageScannerResolution: ...
    @winrt_commethod(17)
    def put_DesiredResolution(self, value: win32more.Windows.Devices.Scanners.ImageScannerResolution) -> Void: ...
    @winrt_commethod(18)
    def get_ActualResolution(self) -> win32more.Windows.Devices.Scanners.ImageScannerResolution: ...
    @winrt_commethod(19)
    def get_DefaultColorMode(self) -> win32more.Windows.Devices.Scanners.ImageScannerColorMode: ...
    @winrt_commethod(20)
    def get_ColorMode(self) -> win32more.Windows.Devices.Scanners.ImageScannerColorMode: ...
    @winrt_commethod(21)
    def put_ColorMode(self, value: win32more.Windows.Devices.Scanners.ImageScannerColorMode) -> Void: ...
    @winrt_commethod(22)
    def IsColorModeSupported(self, value: win32more.Windows.Devices.Scanners.ImageScannerColorMode) -> Boolean: ...
    @winrt_commethod(23)
    def get_MinBrightness(self) -> Int32: ...
    @winrt_commethod(24)
    def get_MaxBrightness(self) -> Int32: ...
    @winrt_commethod(25)
    def get_BrightnessStep(self) -> UInt32: ...
    @winrt_commethod(26)
    def get_DefaultBrightness(self) -> Int32: ...
    @winrt_commethod(27)
    def get_Brightness(self) -> Int32: ...
    @winrt_commethod(28)
    def put_Brightness(self, value: Int32) -> Void: ...
    @winrt_commethod(29)
    def get_MinContrast(self) -> Int32: ...
    @winrt_commethod(30)
    def get_MaxContrast(self) -> Int32: ...
    @winrt_commethod(31)
    def get_ContrastStep(self) -> UInt32: ...
    @winrt_commethod(32)
    def get_DefaultContrast(self) -> Int32: ...
    @winrt_commethod(33)
    def get_Contrast(self) -> Int32: ...
    @winrt_commethod(34)
    def put_Contrast(self, value: Int32) -> Void: ...
    ActualResolution = property(get_ActualResolution, None)
    AutoCroppingMode = property(get_AutoCroppingMode, put_AutoCroppingMode)
    Brightness = property(get_Brightness, put_Brightness)
    BrightnessStep = property(get_BrightnessStep, None)
    ColorMode = property(get_ColorMode, put_ColorMode)
    Contrast = property(get_Contrast, put_Contrast)
    ContrastStep = property(get_ContrastStep, None)
    DefaultBrightness = property(get_DefaultBrightness, None)
    DefaultColorMode = property(get_DefaultColorMode, None)
    DefaultContrast = property(get_DefaultContrast, None)
    DesiredResolution = property(get_DesiredResolution, put_DesiredResolution)
    MaxBrightness = property(get_MaxBrightness, None)
    MaxContrast = property(get_MaxContrast, None)
    MaxResolution = property(get_MaxResolution, None)
    MaxScanArea = property(get_MaxScanArea, None)
    MinBrightness = property(get_MinBrightness, None)
    MinContrast = property(get_MinContrast, None)
    MinResolution = property(get_MinResolution, None)
    MinScanArea = property(get_MinScanArea, None)
    OpticalResolution = property(get_OpticalResolution, None)
    SelectedScanRegion = property(get_SelectedScanRegion, put_SelectedScanRegion)
class IImageScannerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Scanners.IImageScannerStatics'
    _iid_ = Guid('{bc57e70e-d804-4477-9fb5-b911b5473897}')
    @winrt_commethod(6)
    def FromIdAsync(self, deviceId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.Scanners.ImageScanner]: ...
    @winrt_commethod(7)
    def GetDeviceSelector(self) -> WinRT_String: ...
class ImageScanner(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.Scanners.IImageScanner
    _classid_ = 'Windows.Devices.Scanners.ImageScanner'
    @winrt_mixinmethod
    def get_DeviceId(self: win32more.Windows.Devices.Scanners.IImageScanner) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_DefaultScanSource(self: win32more.Windows.Devices.Scanners.IImageScanner) -> win32more.Windows.Devices.Scanners.ImageScannerScanSource: ...
    @winrt_mixinmethod
    def IsScanSourceSupported(self: win32more.Windows.Devices.Scanners.IImageScanner, value: win32more.Windows.Devices.Scanners.ImageScannerScanSource) -> Boolean: ...
    @winrt_mixinmethod
    def get_FlatbedConfiguration(self: win32more.Windows.Devices.Scanners.IImageScanner) -> win32more.Windows.Devices.Scanners.ImageScannerFlatbedConfiguration: ...
    @winrt_mixinmethod
    def get_FeederConfiguration(self: win32more.Windows.Devices.Scanners.IImageScanner) -> win32more.Windows.Devices.Scanners.ImageScannerFeederConfiguration: ...
    @winrt_mixinmethod
    def get_AutoConfiguration(self: win32more.Windows.Devices.Scanners.IImageScanner) -> win32more.Windows.Devices.Scanners.ImageScannerAutoConfiguration: ...
    @winrt_mixinmethod
    def IsPreviewSupported(self: win32more.Windows.Devices.Scanners.IImageScanner, scanSource: win32more.Windows.Devices.Scanners.ImageScannerScanSource) -> Boolean: ...
    @winrt_mixinmethod
    def ScanPreviewToStreamAsync(self: win32more.Windows.Devices.Scanners.IImageScanner, scanSource: win32more.Windows.Devices.Scanners.ImageScannerScanSource, targetStream: win32more.Windows.Storage.Streams.IRandomAccessStream) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.Scanners.ImageScannerPreviewResult]: ...
    @winrt_mixinmethod
    def ScanFilesToFolderAsync(self: win32more.Windows.Devices.Scanners.IImageScanner, scanSource: win32more.Windows.Devices.Scanners.ImageScannerScanSource, storageFolder: win32more.Windows.Storage.StorageFolder) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Windows.Devices.Scanners.ImageScannerScanResult, UInt32]: ...
    @winrt_classmethod
    def FromIdAsync(cls: win32more.Windows.Devices.Scanners.IImageScannerStatics, deviceId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.Scanners.ImageScanner]: ...
    @winrt_classmethod
    def GetDeviceSelector(cls: win32more.Windows.Devices.Scanners.IImageScannerStatics) -> WinRT_String: ...
    AutoConfiguration = property(get_AutoConfiguration, None)
    DefaultScanSource = property(get_DefaultScanSource, None)
    DeviceId = property(get_DeviceId, None)
    FeederConfiguration = property(get_FeederConfiguration, None)
    FlatbedConfiguration = property(get_FlatbedConfiguration, None)
class ImageScannerAutoConfiguration(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.Scanners.IImageScannerFormatConfiguration
    _classid_ = 'Windows.Devices.Scanners.ImageScannerAutoConfiguration'
    @winrt_mixinmethod
    def get_DefaultFormat(self: win32more.Windows.Devices.Scanners.IImageScannerFormatConfiguration) -> win32more.Windows.Devices.Scanners.ImageScannerFormat: ...
    @winrt_mixinmethod
    def get_Format(self: win32more.Windows.Devices.Scanners.IImageScannerFormatConfiguration) -> win32more.Windows.Devices.Scanners.ImageScannerFormat: ...
    @winrt_mixinmethod
    def put_Format(self: win32more.Windows.Devices.Scanners.IImageScannerFormatConfiguration, value: win32more.Windows.Devices.Scanners.ImageScannerFormat) -> Void: ...
    @winrt_mixinmethod
    def IsFormatSupported(self: win32more.Windows.Devices.Scanners.IImageScannerFormatConfiguration, value: win32more.Windows.Devices.Scanners.ImageScannerFormat) -> Boolean: ...
    DefaultFormat = property(get_DefaultFormat, None)
    Format = property(get_Format, put_Format)
class ImageScannerAutoCroppingMode(Enum, Int32):
    Disabled = 0
    SingleRegion = 1
    MultipleRegion = 2
class ImageScannerColorMode(Enum, Int32):
    Color = 0
    Grayscale = 1
    Monochrome = 2
    AutoColor = 3
class ImageScannerFeederConfiguration(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.Scanners.IImageScannerFormatConfiguration
    _classid_ = 'Windows.Devices.Scanners.ImageScannerFeederConfiguration'
    @winrt_mixinmethod
    def get_DefaultFormat(self: win32more.Windows.Devices.Scanners.IImageScannerFormatConfiguration) -> win32more.Windows.Devices.Scanners.ImageScannerFormat: ...
    @winrt_mixinmethod
    def get_Format(self: win32more.Windows.Devices.Scanners.IImageScannerFormatConfiguration) -> win32more.Windows.Devices.Scanners.ImageScannerFormat: ...
    @winrt_mixinmethod
    def put_Format(self: win32more.Windows.Devices.Scanners.IImageScannerFormatConfiguration, value: win32more.Windows.Devices.Scanners.ImageScannerFormat) -> Void: ...
    @winrt_mixinmethod
    def IsFormatSupported(self: win32more.Windows.Devices.Scanners.IImageScannerFormatConfiguration, value: win32more.Windows.Devices.Scanners.ImageScannerFormat) -> Boolean: ...
    @winrt_mixinmethod
    def get_MinScanArea(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration) -> win32more.Windows.Foundation.Size: ...
    @winrt_mixinmethod
    def get_MaxScanArea(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration) -> win32more.Windows.Foundation.Size: ...
    @winrt_mixinmethod
    def get_SelectedScanRegion(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration) -> win32more.Windows.Foundation.Rect: ...
    @winrt_mixinmethod
    def put_SelectedScanRegion(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration, value: win32more.Windows.Foundation.Rect) -> Void: ...
    @winrt_mixinmethod
    def get_AutoCroppingMode(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration) -> win32more.Windows.Devices.Scanners.ImageScannerAutoCroppingMode: ...
    @winrt_mixinmethod
    def put_AutoCroppingMode(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration, value: win32more.Windows.Devices.Scanners.ImageScannerAutoCroppingMode) -> Void: ...
    @winrt_mixinmethod
    def IsAutoCroppingModeSupported(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration, value: win32more.Windows.Devices.Scanners.ImageScannerAutoCroppingMode) -> Boolean: ...
    @winrt_mixinmethod
    def get_MinResolution(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration) -> win32more.Windows.Devices.Scanners.ImageScannerResolution: ...
    @winrt_mixinmethod
    def get_MaxResolution(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration) -> win32more.Windows.Devices.Scanners.ImageScannerResolution: ...
    @winrt_mixinmethod
    def get_OpticalResolution(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration) -> win32more.Windows.Devices.Scanners.ImageScannerResolution: ...
    @winrt_mixinmethod
    def get_DesiredResolution(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration) -> win32more.Windows.Devices.Scanners.ImageScannerResolution: ...
    @winrt_mixinmethod
    def put_DesiredResolution(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration, value: win32more.Windows.Devices.Scanners.ImageScannerResolution) -> Void: ...
    @winrt_mixinmethod
    def get_ActualResolution(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration) -> win32more.Windows.Devices.Scanners.ImageScannerResolution: ...
    @winrt_mixinmethod
    def get_DefaultColorMode(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration) -> win32more.Windows.Devices.Scanners.ImageScannerColorMode: ...
    @winrt_mixinmethod
    def get_ColorMode(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration) -> win32more.Windows.Devices.Scanners.ImageScannerColorMode: ...
    @winrt_mixinmethod
    def put_ColorMode(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration, value: win32more.Windows.Devices.Scanners.ImageScannerColorMode) -> Void: ...
    @winrt_mixinmethod
    def IsColorModeSupported(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration, value: win32more.Windows.Devices.Scanners.ImageScannerColorMode) -> Boolean: ...
    @winrt_mixinmethod
    def get_MinBrightness(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration) -> Int32: ...
    @winrt_mixinmethod
    def get_MaxBrightness(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration) -> Int32: ...
    @winrt_mixinmethod
    def get_BrightnessStep(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration) -> UInt32: ...
    @winrt_mixinmethod
    def get_DefaultBrightness(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration) -> Int32: ...
    @winrt_mixinmethod
    def get_Brightness(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration) -> Int32: ...
    @winrt_mixinmethod
    def put_Brightness(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_MinContrast(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration) -> Int32: ...
    @winrt_mixinmethod
    def get_MaxContrast(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration) -> Int32: ...
    @winrt_mixinmethod
    def get_ContrastStep(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration) -> UInt32: ...
    @winrt_mixinmethod
    def get_DefaultContrast(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration) -> Int32: ...
    @winrt_mixinmethod
    def get_Contrast(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration) -> Int32: ...
    @winrt_mixinmethod
    def put_Contrast(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_CanAutoDetectPageSize(self: win32more.Windows.Devices.Scanners.IImageScannerFeederConfiguration) -> Boolean: ...
    @winrt_mixinmethod
    def get_AutoDetectPageSize(self: win32more.Windows.Devices.Scanners.IImageScannerFeederConfiguration) -> Boolean: ...
    @winrt_mixinmethod
    def put_AutoDetectPageSize(self: win32more.Windows.Devices.Scanners.IImageScannerFeederConfiguration, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_PageSize(self: win32more.Windows.Devices.Scanners.IImageScannerFeederConfiguration) -> win32more.Windows.Graphics.Printing.PrintMediaSize: ...
    @winrt_mixinmethod
    def put_PageSize(self: win32more.Windows.Devices.Scanners.IImageScannerFeederConfiguration, value: win32more.Windows.Graphics.Printing.PrintMediaSize) -> Void: ...
    @winrt_mixinmethod
    def get_PageOrientation(self: win32more.Windows.Devices.Scanners.IImageScannerFeederConfiguration) -> win32more.Windows.Graphics.Printing.PrintOrientation: ...
    @winrt_mixinmethod
    def put_PageOrientation(self: win32more.Windows.Devices.Scanners.IImageScannerFeederConfiguration, value: win32more.Windows.Graphics.Printing.PrintOrientation) -> Void: ...
    @winrt_mixinmethod
    def get_PageSizeDimensions(self: win32more.Windows.Devices.Scanners.IImageScannerFeederConfiguration) -> win32more.Windows.Foundation.Size: ...
    @winrt_mixinmethod
    def IsPageSizeSupported(self: win32more.Windows.Devices.Scanners.IImageScannerFeederConfiguration, pageSize: win32more.Windows.Graphics.Printing.PrintMediaSize, pageOrientation: win32more.Windows.Graphics.Printing.PrintOrientation) -> Boolean: ...
    @winrt_mixinmethod
    def get_MaxNumberOfPages(self: win32more.Windows.Devices.Scanners.IImageScannerFeederConfiguration) -> UInt32: ...
    @winrt_mixinmethod
    def put_MaxNumberOfPages(self: win32more.Windows.Devices.Scanners.IImageScannerFeederConfiguration, value: UInt32) -> Void: ...
    @winrt_mixinmethod
    def get_CanScanDuplex(self: win32more.Windows.Devices.Scanners.IImageScannerFeederConfiguration) -> Boolean: ...
    @winrt_mixinmethod
    def get_Duplex(self: win32more.Windows.Devices.Scanners.IImageScannerFeederConfiguration) -> Boolean: ...
    @winrt_mixinmethod
    def put_Duplex(self: win32more.Windows.Devices.Scanners.IImageScannerFeederConfiguration, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_CanScanAhead(self: win32more.Windows.Devices.Scanners.IImageScannerFeederConfiguration) -> Boolean: ...
    @winrt_mixinmethod
    def get_ScanAhead(self: win32more.Windows.Devices.Scanners.IImageScannerFeederConfiguration) -> Boolean: ...
    @winrt_mixinmethod
    def put_ScanAhead(self: win32more.Windows.Devices.Scanners.IImageScannerFeederConfiguration, value: Boolean) -> Void: ...
    ActualResolution = property(get_ActualResolution, None)
    AutoCroppingMode = property(get_AutoCroppingMode, put_AutoCroppingMode)
    AutoDetectPageSize = property(get_AutoDetectPageSize, put_AutoDetectPageSize)
    Brightness = property(get_Brightness, put_Brightness)
    BrightnessStep = property(get_BrightnessStep, None)
    CanAutoDetectPageSize = property(get_CanAutoDetectPageSize, None)
    CanScanAhead = property(get_CanScanAhead, None)
    CanScanDuplex = property(get_CanScanDuplex, None)
    ColorMode = property(get_ColorMode, put_ColorMode)
    Contrast = property(get_Contrast, put_Contrast)
    ContrastStep = property(get_ContrastStep, None)
    DefaultBrightness = property(get_DefaultBrightness, None)
    DefaultColorMode = property(get_DefaultColorMode, None)
    DefaultContrast = property(get_DefaultContrast, None)
    DefaultFormat = property(get_DefaultFormat, None)
    DesiredResolution = property(get_DesiredResolution, put_DesiredResolution)
    Duplex = property(get_Duplex, put_Duplex)
    Format = property(get_Format, put_Format)
    MaxBrightness = property(get_MaxBrightness, None)
    MaxContrast = property(get_MaxContrast, None)
    MaxNumberOfPages = property(get_MaxNumberOfPages, put_MaxNumberOfPages)
    MaxResolution = property(get_MaxResolution, None)
    MaxScanArea = property(get_MaxScanArea, None)
    MinBrightness = property(get_MinBrightness, None)
    MinContrast = property(get_MinContrast, None)
    MinResolution = property(get_MinResolution, None)
    MinScanArea = property(get_MinScanArea, None)
    OpticalResolution = property(get_OpticalResolution, None)
    PageOrientation = property(get_PageOrientation, put_PageOrientation)
    PageSize = property(get_PageSize, put_PageSize)
    PageSizeDimensions = property(get_PageSizeDimensions, None)
    ScanAhead = property(get_ScanAhead, put_ScanAhead)
    SelectedScanRegion = property(get_SelectedScanRegion, put_SelectedScanRegion)
class ImageScannerFlatbedConfiguration(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.Scanners.IImageScannerFormatConfiguration
    _classid_ = 'Windows.Devices.Scanners.ImageScannerFlatbedConfiguration'
    @winrt_mixinmethod
    def get_DefaultFormat(self: win32more.Windows.Devices.Scanners.IImageScannerFormatConfiguration) -> win32more.Windows.Devices.Scanners.ImageScannerFormat: ...
    @winrt_mixinmethod
    def get_Format(self: win32more.Windows.Devices.Scanners.IImageScannerFormatConfiguration) -> win32more.Windows.Devices.Scanners.ImageScannerFormat: ...
    @winrt_mixinmethod
    def put_Format(self: win32more.Windows.Devices.Scanners.IImageScannerFormatConfiguration, value: win32more.Windows.Devices.Scanners.ImageScannerFormat) -> Void: ...
    @winrt_mixinmethod
    def IsFormatSupported(self: win32more.Windows.Devices.Scanners.IImageScannerFormatConfiguration, value: win32more.Windows.Devices.Scanners.ImageScannerFormat) -> Boolean: ...
    @winrt_mixinmethod
    def get_MinScanArea(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration) -> win32more.Windows.Foundation.Size: ...
    @winrt_mixinmethod
    def get_MaxScanArea(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration) -> win32more.Windows.Foundation.Size: ...
    @winrt_mixinmethod
    def get_SelectedScanRegion(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration) -> win32more.Windows.Foundation.Rect: ...
    @winrt_mixinmethod
    def put_SelectedScanRegion(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration, value: win32more.Windows.Foundation.Rect) -> Void: ...
    @winrt_mixinmethod
    def get_AutoCroppingMode(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration) -> win32more.Windows.Devices.Scanners.ImageScannerAutoCroppingMode: ...
    @winrt_mixinmethod
    def put_AutoCroppingMode(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration, value: win32more.Windows.Devices.Scanners.ImageScannerAutoCroppingMode) -> Void: ...
    @winrt_mixinmethod
    def IsAutoCroppingModeSupported(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration, value: win32more.Windows.Devices.Scanners.ImageScannerAutoCroppingMode) -> Boolean: ...
    @winrt_mixinmethod
    def get_MinResolution(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration) -> win32more.Windows.Devices.Scanners.ImageScannerResolution: ...
    @winrt_mixinmethod
    def get_MaxResolution(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration) -> win32more.Windows.Devices.Scanners.ImageScannerResolution: ...
    @winrt_mixinmethod
    def get_OpticalResolution(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration) -> win32more.Windows.Devices.Scanners.ImageScannerResolution: ...
    @winrt_mixinmethod
    def get_DesiredResolution(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration) -> win32more.Windows.Devices.Scanners.ImageScannerResolution: ...
    @winrt_mixinmethod
    def put_DesiredResolution(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration, value: win32more.Windows.Devices.Scanners.ImageScannerResolution) -> Void: ...
    @winrt_mixinmethod
    def get_ActualResolution(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration) -> win32more.Windows.Devices.Scanners.ImageScannerResolution: ...
    @winrt_mixinmethod
    def get_DefaultColorMode(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration) -> win32more.Windows.Devices.Scanners.ImageScannerColorMode: ...
    @winrt_mixinmethod
    def get_ColorMode(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration) -> win32more.Windows.Devices.Scanners.ImageScannerColorMode: ...
    @winrt_mixinmethod
    def put_ColorMode(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration, value: win32more.Windows.Devices.Scanners.ImageScannerColorMode) -> Void: ...
    @winrt_mixinmethod
    def IsColorModeSupported(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration, value: win32more.Windows.Devices.Scanners.ImageScannerColorMode) -> Boolean: ...
    @winrt_mixinmethod
    def get_MinBrightness(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration) -> Int32: ...
    @winrt_mixinmethod
    def get_MaxBrightness(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration) -> Int32: ...
    @winrt_mixinmethod
    def get_BrightnessStep(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration) -> UInt32: ...
    @winrt_mixinmethod
    def get_DefaultBrightness(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration) -> Int32: ...
    @winrt_mixinmethod
    def get_Brightness(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration) -> Int32: ...
    @winrt_mixinmethod
    def put_Brightness(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_MinContrast(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration) -> Int32: ...
    @winrt_mixinmethod
    def get_MaxContrast(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration) -> Int32: ...
    @winrt_mixinmethod
    def get_ContrastStep(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration) -> UInt32: ...
    @winrt_mixinmethod
    def get_DefaultContrast(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration) -> Int32: ...
    @winrt_mixinmethod
    def get_Contrast(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration) -> Int32: ...
    @winrt_mixinmethod
    def put_Contrast(self: win32more.Windows.Devices.Scanners.IImageScannerSourceConfiguration, value: Int32) -> Void: ...
    ActualResolution = property(get_ActualResolution, None)
    AutoCroppingMode = property(get_AutoCroppingMode, put_AutoCroppingMode)
    Brightness = property(get_Brightness, put_Brightness)
    BrightnessStep = property(get_BrightnessStep, None)
    ColorMode = property(get_ColorMode, put_ColorMode)
    Contrast = property(get_Contrast, put_Contrast)
    ContrastStep = property(get_ContrastStep, None)
    DefaultBrightness = property(get_DefaultBrightness, None)
    DefaultColorMode = property(get_DefaultColorMode, None)
    DefaultContrast = property(get_DefaultContrast, None)
    DefaultFormat = property(get_DefaultFormat, None)
    DesiredResolution = property(get_DesiredResolution, put_DesiredResolution)
    Format = property(get_Format, put_Format)
    MaxBrightness = property(get_MaxBrightness, None)
    MaxContrast = property(get_MaxContrast, None)
    MaxResolution = property(get_MaxResolution, None)
    MaxScanArea = property(get_MaxScanArea, None)
    MinBrightness = property(get_MinBrightness, None)
    MinContrast = property(get_MinContrast, None)
    MinResolution = property(get_MinResolution, None)
    MinScanArea = property(get_MinScanArea, None)
    OpticalResolution = property(get_OpticalResolution, None)
    SelectedScanRegion = property(get_SelectedScanRegion, put_SelectedScanRegion)
class ImageScannerFormat(Enum, Int32):
    Jpeg = 0
    Png = 1
    DeviceIndependentBitmap = 2
    Tiff = 3
    Xps = 4
    OpenXps = 5
    Pdf = 6
class ImageScannerPreviewResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.Scanners.IImageScannerPreviewResult
    _classid_ = 'Windows.Devices.Scanners.ImageScannerPreviewResult'
    @winrt_mixinmethod
    def get_Succeeded(self: win32more.Windows.Devices.Scanners.IImageScannerPreviewResult) -> Boolean: ...
    @winrt_mixinmethod
    def get_Format(self: win32more.Windows.Devices.Scanners.IImageScannerPreviewResult) -> win32more.Windows.Devices.Scanners.ImageScannerFormat: ...
    Format = property(get_Format, None)
    Succeeded = property(get_Succeeded, None)
class ImageScannerResolution(Structure):
    DpiX: Single
    DpiY: Single
class ImageScannerScanResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.Scanners.IImageScannerScanResult
    _classid_ = 'Windows.Devices.Scanners.ImageScannerScanResult'
    @winrt_mixinmethod
    def get_ScannedFiles(self: win32more.Windows.Devices.Scanners.IImageScannerScanResult) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Storage.StorageFile]: ...
    ScannedFiles = property(get_ScannedFiles, None)
class ImageScannerScanSource(Enum, Int32):
    Default = 0
    Flatbed = 1
    Feeder = 2
    AutoConfigured = 3
ScannerDeviceContract: UInt32 = 65536


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Graphics
import win32more.Windows.Graphics.Display
import win32more.Windows.Storage.Streams
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.WinRT
class AdvancedColorInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Display.IAdvancedColorInfo
    _classid_ = 'Windows.Graphics.Display.AdvancedColorInfo'
    @winrt_mixinmethod
    def get_CurrentAdvancedColorKind(self: win32more.Windows.Graphics.Display.IAdvancedColorInfo) -> win32more.Windows.Graphics.Display.AdvancedColorKind: ...
    @winrt_mixinmethod
    def get_RedPrimary(self: win32more.Windows.Graphics.Display.IAdvancedColorInfo) -> win32more.Windows.Foundation.Point: ...
    @winrt_mixinmethod
    def get_GreenPrimary(self: win32more.Windows.Graphics.Display.IAdvancedColorInfo) -> win32more.Windows.Foundation.Point: ...
    @winrt_mixinmethod
    def get_BluePrimary(self: win32more.Windows.Graphics.Display.IAdvancedColorInfo) -> win32more.Windows.Foundation.Point: ...
    @winrt_mixinmethod
    def get_WhitePoint(self: win32more.Windows.Graphics.Display.IAdvancedColorInfo) -> win32more.Windows.Foundation.Point: ...
    @winrt_mixinmethod
    def get_MaxLuminanceInNits(self: win32more.Windows.Graphics.Display.IAdvancedColorInfo) -> Single: ...
    @winrt_mixinmethod
    def get_MinLuminanceInNits(self: win32more.Windows.Graphics.Display.IAdvancedColorInfo) -> Single: ...
    @winrt_mixinmethod
    def get_MaxAverageFullFrameLuminanceInNits(self: win32more.Windows.Graphics.Display.IAdvancedColorInfo) -> Single: ...
    @winrt_mixinmethod
    def get_SdrWhiteLevelInNits(self: win32more.Windows.Graphics.Display.IAdvancedColorInfo) -> Single: ...
    @winrt_mixinmethod
    def IsHdrMetadataFormatCurrentlySupported(self: win32more.Windows.Graphics.Display.IAdvancedColorInfo, format: win32more.Windows.Graphics.Display.HdrMetadataFormat) -> Boolean: ...
    @winrt_mixinmethod
    def IsAdvancedColorKindAvailable(self: win32more.Windows.Graphics.Display.IAdvancedColorInfo, kind: win32more.Windows.Graphics.Display.AdvancedColorKind) -> Boolean: ...
    BluePrimary = property(get_BluePrimary, None)
    CurrentAdvancedColorKind = property(get_CurrentAdvancedColorKind, None)
    GreenPrimary = property(get_GreenPrimary, None)
    MaxAverageFullFrameLuminanceInNits = property(get_MaxAverageFullFrameLuminanceInNits, None)
    MaxLuminanceInNits = property(get_MaxLuminanceInNits, None)
    MinLuminanceInNits = property(get_MinLuminanceInNits, None)
    RedPrimary = property(get_RedPrimary, None)
    SdrWhiteLevelInNits = property(get_SdrWhiteLevelInNits, None)
    WhitePoint = property(get_WhitePoint, None)
class AdvancedColorKind(Enum, Int32):
    StandardDynamicRange = 0
    WideColorGamut = 1
    HighDynamicRange = 2
class BrightnessOverride(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Display.IBrightnessOverride
    _classid_ = 'Windows.Graphics.Display.BrightnessOverride'
    @winrt_mixinmethod
    def get_IsSupported(self: win32more.Windows.Graphics.Display.IBrightnessOverride) -> Boolean: ...
    @winrt_mixinmethod
    def get_IsOverrideActive(self: win32more.Windows.Graphics.Display.IBrightnessOverride) -> Boolean: ...
    @winrt_mixinmethod
    def get_BrightnessLevel(self: win32more.Windows.Graphics.Display.IBrightnessOverride) -> Double: ...
    @winrt_mixinmethod
    def SetBrightnessLevel(self: win32more.Windows.Graphics.Display.IBrightnessOverride, brightnessLevel: Double, options: win32more.Windows.Graphics.Display.DisplayBrightnessOverrideOptions) -> Void: ...
    @winrt_mixinmethod
    def SetBrightnessScenario(self: win32more.Windows.Graphics.Display.IBrightnessOverride, scenario: win32more.Windows.Graphics.Display.DisplayBrightnessScenario, options: win32more.Windows.Graphics.Display.DisplayBrightnessOverrideOptions) -> Void: ...
    @winrt_mixinmethod
    def GetLevelForScenario(self: win32more.Windows.Graphics.Display.IBrightnessOverride, scenario: win32more.Windows.Graphics.Display.DisplayBrightnessScenario) -> Double: ...
    @winrt_mixinmethod
    def StartOverride(self: win32more.Windows.Graphics.Display.IBrightnessOverride) -> Void: ...
    @winrt_mixinmethod
    def StopOverride(self: win32more.Windows.Graphics.Display.IBrightnessOverride) -> Void: ...
    @winrt_mixinmethod
    def add_IsSupportedChanged(self: win32more.Windows.Graphics.Display.IBrightnessOverride, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Graphics.Display.BrightnessOverride, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_IsSupportedChanged(self: win32more.Windows.Graphics.Display.IBrightnessOverride, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_IsOverrideActiveChanged(self: win32more.Windows.Graphics.Display.IBrightnessOverride, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Graphics.Display.BrightnessOverride, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_IsOverrideActiveChanged(self: win32more.Windows.Graphics.Display.IBrightnessOverride, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_BrightnessLevelChanged(self: win32more.Windows.Graphics.Display.IBrightnessOverride, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Graphics.Display.BrightnessOverride, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_BrightnessLevelChanged(self: win32more.Windows.Graphics.Display.IBrightnessOverride, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def GetDefaultForSystem(cls: win32more.Windows.Graphics.Display.IBrightnessOverrideStatics) -> win32more.Windows.Graphics.Display.BrightnessOverride: ...
    @winrt_classmethod
    def GetForCurrentView(cls: win32more.Windows.Graphics.Display.IBrightnessOverrideStatics) -> win32more.Windows.Graphics.Display.BrightnessOverride: ...
    @winrt_classmethod
    def SaveForSystemAsync(cls: win32more.Windows.Graphics.Display.IBrightnessOverrideStatics, value: win32more.Windows.Graphics.Display.BrightnessOverride) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    BrightnessLevel = property(get_BrightnessLevel, None)
    IsOverrideActive = property(get_IsOverrideActive, None)
    IsSupported = property(get_IsSupported, None)
    IsSupportedChanged = event()
    IsOverrideActiveChanged = event()
    BrightnessLevelChanged = event()
class BrightnessOverrideSettings(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Display.IBrightnessOverrideSettings
    _classid_ = 'Windows.Graphics.Display.BrightnessOverrideSettings'
    @winrt_mixinmethod
    def get_DesiredLevel(self: win32more.Windows.Graphics.Display.IBrightnessOverrideSettings) -> Double: ...
    @winrt_mixinmethod
    def get_DesiredNits(self: win32more.Windows.Graphics.Display.IBrightnessOverrideSettings) -> Single: ...
    @winrt_classmethod
    def CreateFromLevel(cls: win32more.Windows.Graphics.Display.IBrightnessOverrideSettingsStatics, level: Double) -> win32more.Windows.Graphics.Display.BrightnessOverrideSettings: ...
    @winrt_classmethod
    def CreateFromNits(cls: win32more.Windows.Graphics.Display.IBrightnessOverrideSettingsStatics, nits: Single) -> win32more.Windows.Graphics.Display.BrightnessOverrideSettings: ...
    @winrt_classmethod
    def CreateFromDisplayBrightnessOverrideScenario(cls: win32more.Windows.Graphics.Display.IBrightnessOverrideSettingsStatics, overrideScenario: win32more.Windows.Graphics.Display.DisplayBrightnessOverrideScenario) -> win32more.Windows.Graphics.Display.BrightnessOverrideSettings: ...
    DesiredLevel = property(get_DesiredLevel, None)
    DesiredNits = property(get_DesiredNits, None)
class ColorOverrideSettings(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Display.IColorOverrideSettings
    _classid_ = 'Windows.Graphics.Display.ColorOverrideSettings'
    @winrt_mixinmethod
    def get_DesiredDisplayColorOverrideScenario(self: win32more.Windows.Graphics.Display.IColorOverrideSettings) -> win32more.Windows.Graphics.Display.DisplayColorOverrideScenario: ...
    @winrt_classmethod
    def CreateFromDisplayColorOverrideScenario(cls: win32more.Windows.Graphics.Display.IColorOverrideSettingsStatics, overrideScenario: win32more.Windows.Graphics.Display.DisplayColorOverrideScenario) -> win32more.Windows.Graphics.Display.ColorOverrideSettings: ...
    DesiredDisplayColorOverrideScenario = property(get_DesiredDisplayColorOverrideScenario, None)
class DisplayBrightnessOverrideOptions(Enum, UInt32):
    None_ = 0
    UseDimmedPolicyWhenBatteryIsLow = 1
class DisplayBrightnessOverrideScenario(Enum, Int32):
    IdleBrightness = 0
    BarcodeReadingBrightness = 1
    FullBrightness = 2
class DisplayBrightnessScenario(Enum, Int32):
    DefaultBrightness = 0
    IdleBrightness = 1
    BarcodeReadingBrightness = 2
    FullBrightness = 3
class DisplayColorOverrideScenario(Enum, Int32):
    Accurate = 0
class DisplayEnhancementOverride(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Display.IDisplayEnhancementOverride
    _classid_ = 'Windows.Graphics.Display.DisplayEnhancementOverride'
    @winrt_mixinmethod
    def get_ColorOverrideSettings(self: win32more.Windows.Graphics.Display.IDisplayEnhancementOverride) -> win32more.Windows.Graphics.Display.ColorOverrideSettings: ...
    @winrt_mixinmethod
    def put_ColorOverrideSettings(self: win32more.Windows.Graphics.Display.IDisplayEnhancementOverride, value: win32more.Windows.Graphics.Display.ColorOverrideSettings) -> Void: ...
    @winrt_mixinmethod
    def get_BrightnessOverrideSettings(self: win32more.Windows.Graphics.Display.IDisplayEnhancementOverride) -> win32more.Windows.Graphics.Display.BrightnessOverrideSettings: ...
    @winrt_mixinmethod
    def put_BrightnessOverrideSettings(self: win32more.Windows.Graphics.Display.IDisplayEnhancementOverride, value: win32more.Windows.Graphics.Display.BrightnessOverrideSettings) -> Void: ...
    @winrt_mixinmethod
    def get_CanOverride(self: win32more.Windows.Graphics.Display.IDisplayEnhancementOverride) -> Boolean: ...
    @winrt_mixinmethod
    def get_IsOverrideActive(self: win32more.Windows.Graphics.Display.IDisplayEnhancementOverride) -> Boolean: ...
    @winrt_mixinmethod
    def GetCurrentDisplayEnhancementOverrideCapabilities(self: win32more.Windows.Graphics.Display.IDisplayEnhancementOverride) -> win32more.Windows.Graphics.Display.DisplayEnhancementOverrideCapabilities: ...
    @winrt_mixinmethod
    def RequestOverride(self: win32more.Windows.Graphics.Display.IDisplayEnhancementOverride) -> Void: ...
    @winrt_mixinmethod
    def StopOverride(self: win32more.Windows.Graphics.Display.IDisplayEnhancementOverride) -> Void: ...
    @winrt_mixinmethod
    def add_CanOverrideChanged(self: win32more.Windows.Graphics.Display.IDisplayEnhancementOverride, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Graphics.Display.DisplayEnhancementOverride, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_CanOverrideChanged(self: win32more.Windows.Graphics.Display.IDisplayEnhancementOverride, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_IsOverrideActiveChanged(self: win32more.Windows.Graphics.Display.IDisplayEnhancementOverride, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Graphics.Display.DisplayEnhancementOverride, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_IsOverrideActiveChanged(self: win32more.Windows.Graphics.Display.IDisplayEnhancementOverride, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_DisplayEnhancementOverrideCapabilitiesChanged(self: win32more.Windows.Graphics.Display.IDisplayEnhancementOverride, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Graphics.Display.DisplayEnhancementOverride, win32more.Windows.Graphics.Display.DisplayEnhancementOverrideCapabilitiesChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_DisplayEnhancementOverrideCapabilitiesChanged(self: win32more.Windows.Graphics.Display.IDisplayEnhancementOverride, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def GetForCurrentView(cls: win32more.Windows.Graphics.Display.IDisplayEnhancementOverrideStatics) -> win32more.Windows.Graphics.Display.DisplayEnhancementOverride: ...
    BrightnessOverrideSettings = property(get_BrightnessOverrideSettings, put_BrightnessOverrideSettings)
    CanOverride = property(get_CanOverride, None)
    ColorOverrideSettings = property(get_ColorOverrideSettings, put_ColorOverrideSettings)
    IsOverrideActive = property(get_IsOverrideActive, None)
    CanOverrideChanged = event()
    IsOverrideActiveChanged = event()
    DisplayEnhancementOverrideCapabilitiesChanged = event()
class DisplayEnhancementOverrideCapabilities(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Display.IDisplayEnhancementOverrideCapabilities
    _classid_ = 'Windows.Graphics.Display.DisplayEnhancementOverrideCapabilities'
    @winrt_mixinmethod
    def get_IsBrightnessControlSupported(self: win32more.Windows.Graphics.Display.IDisplayEnhancementOverrideCapabilities) -> Boolean: ...
    @winrt_mixinmethod
    def get_IsBrightnessNitsControlSupported(self: win32more.Windows.Graphics.Display.IDisplayEnhancementOverrideCapabilities) -> Boolean: ...
    @winrt_mixinmethod
    def GetSupportedNitRanges(self: win32more.Windows.Graphics.Display.IDisplayEnhancementOverrideCapabilities) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Graphics.Display.NitRange]: ...
    IsBrightnessControlSupported = property(get_IsBrightnessControlSupported, None)
    IsBrightnessNitsControlSupported = property(get_IsBrightnessNitsControlSupported, None)
class DisplayEnhancementOverrideCapabilitiesChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Display.IDisplayEnhancementOverrideCapabilitiesChangedEventArgs
    _classid_ = 'Windows.Graphics.Display.DisplayEnhancementOverrideCapabilitiesChangedEventArgs'
    @winrt_mixinmethod
    def get_Capabilities(self: win32more.Windows.Graphics.Display.IDisplayEnhancementOverrideCapabilitiesChangedEventArgs) -> win32more.Windows.Graphics.Display.DisplayEnhancementOverrideCapabilities: ...
    Capabilities = property(get_Capabilities, None)
class _DisplayInformation_Meta_(ComPtr.__class__):
    pass
class DisplayInformation(ComPtr, metaclass=_DisplayInformation_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Display.IDisplayInformation
    _classid_ = 'Windows.Graphics.Display.DisplayInformation'
    @winrt_mixinmethod
    def get_CurrentOrientation(self: win32more.Windows.Graphics.Display.IDisplayInformation) -> win32more.Windows.Graphics.Display.DisplayOrientations: ...
    @winrt_mixinmethod
    def get_NativeOrientation(self: win32more.Windows.Graphics.Display.IDisplayInformation) -> win32more.Windows.Graphics.Display.DisplayOrientations: ...
    @winrt_mixinmethod
    def add_OrientationChanged(self: win32more.Windows.Graphics.Display.IDisplayInformation, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Graphics.Display.DisplayInformation, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_OrientationChanged(self: win32more.Windows.Graphics.Display.IDisplayInformation, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_ResolutionScale(self: win32more.Windows.Graphics.Display.IDisplayInformation) -> win32more.Windows.Graphics.Display.ResolutionScale: ...
    @winrt_mixinmethod
    def get_LogicalDpi(self: win32more.Windows.Graphics.Display.IDisplayInformation) -> Single: ...
    @winrt_mixinmethod
    def get_RawDpiX(self: win32more.Windows.Graphics.Display.IDisplayInformation) -> Single: ...
    @winrt_mixinmethod
    def get_RawDpiY(self: win32more.Windows.Graphics.Display.IDisplayInformation) -> Single: ...
    @winrt_mixinmethod
    def add_DpiChanged(self: win32more.Windows.Graphics.Display.IDisplayInformation, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Graphics.Display.DisplayInformation, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_DpiChanged(self: win32more.Windows.Graphics.Display.IDisplayInformation, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_StereoEnabled(self: win32more.Windows.Graphics.Display.IDisplayInformation) -> Boolean: ...
    @winrt_mixinmethod
    def add_StereoEnabledChanged(self: win32more.Windows.Graphics.Display.IDisplayInformation, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Graphics.Display.DisplayInformation, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_StereoEnabledChanged(self: win32more.Windows.Graphics.Display.IDisplayInformation, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def GetColorProfileAsync(self: win32more.Windows.Graphics.Display.IDisplayInformation) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.Streams.IRandomAccessStream]: ...
    @winrt_mixinmethod
    def add_ColorProfileChanged(self: win32more.Windows.Graphics.Display.IDisplayInformation, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Graphics.Display.DisplayInformation, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ColorProfileChanged(self: win32more.Windows.Graphics.Display.IDisplayInformation, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_RawPixelsPerViewPixel(self: win32more.Windows.Graphics.Display.IDisplayInformation2) -> Double: ...
    @winrt_mixinmethod
    def get_DiagonalSizeInInches(self: win32more.Windows.Graphics.Display.IDisplayInformation3) -> win32more.Windows.Foundation.IReference[Double]: ...
    @winrt_mixinmethod
    def get_ScreenWidthInRawPixels(self: win32more.Windows.Graphics.Display.IDisplayInformation4) -> UInt32: ...
    @winrt_mixinmethod
    def get_ScreenHeightInRawPixels(self: win32more.Windows.Graphics.Display.IDisplayInformation4) -> UInt32: ...
    @winrt_mixinmethod
    def GetAdvancedColorInfo(self: win32more.Windows.Graphics.Display.IDisplayInformation5) -> win32more.Windows.Graphics.Display.AdvancedColorInfo: ...
    @winrt_mixinmethod
    def add_AdvancedColorInfoChanged(self: win32more.Windows.Graphics.Display.IDisplayInformation5, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Graphics.Display.DisplayInformation, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_AdvancedColorInfoChanged(self: win32more.Windows.Graphics.Display.IDisplayInformation5, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def GetForCurrentView(cls: win32more.Windows.Graphics.Display.IDisplayInformationStatics) -> win32more.Windows.Graphics.Display.DisplayInformation: ...
    @winrt_classmethod
    def get_AutoRotationPreferences(cls: win32more.Windows.Graphics.Display.IDisplayInformationStatics) -> win32more.Windows.Graphics.Display.DisplayOrientations: ...
    @winrt_classmethod
    def put_AutoRotationPreferences(cls: win32more.Windows.Graphics.Display.IDisplayInformationStatics, value: win32more.Windows.Graphics.Display.DisplayOrientations) -> Void: ...
    @winrt_classmethod
    def add_DisplayContentsInvalidated(cls: win32more.Windows.Graphics.Display.IDisplayInformationStatics, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Graphics.Display.DisplayInformation, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_DisplayContentsInvalidated(cls: win32more.Windows.Graphics.Display.IDisplayInformationStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    CurrentOrientation = property(get_CurrentOrientation, None)
    DiagonalSizeInInches = property(get_DiagonalSizeInInches, None)
    LogicalDpi = property(get_LogicalDpi, None)
    NativeOrientation = property(get_NativeOrientation, None)
    RawDpiX = property(get_RawDpiX, None)
    RawDpiY = property(get_RawDpiY, None)
    RawPixelsPerViewPixel = property(get_RawPixelsPerViewPixel, None)
    ResolutionScale = property(get_ResolutionScale, None)
    ScreenHeightInRawPixels = property(get_ScreenHeightInRawPixels, None)
    ScreenWidthInRawPixels = property(get_ScreenWidthInRawPixels, None)
    StereoEnabled = property(get_StereoEnabled, None)
    _DisplayInformation_Meta_.AutoRotationPreferences = property(get_AutoRotationPreferences, put_AutoRotationPreferences)
    OrientationChanged = event()
    DpiChanged = event()
    StereoEnabledChanged = event()
    ColorProfileChanged = event()
    AdvancedColorInfoChanged = event()
class DisplayOrientations(Enum, UInt32):
    None_ = 0
    Landscape = 1
    Portrait = 2
    LandscapeFlipped = 4
    PortraitFlipped = 8
class _DisplayProperties_Meta_(ComPtr.__class__):
    pass
class DisplayProperties(ComPtr, metaclass=_DisplayProperties_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Display.DisplayProperties'
    @winrt_classmethod
    def get_CurrentOrientation(cls: win32more.Windows.Graphics.Display.IDisplayPropertiesStatics) -> win32more.Windows.Graphics.Display.DisplayOrientations: ...
    @winrt_classmethod
    def get_NativeOrientation(cls: win32more.Windows.Graphics.Display.IDisplayPropertiesStatics) -> win32more.Windows.Graphics.Display.DisplayOrientations: ...
    @winrt_classmethod
    def get_AutoRotationPreferences(cls: win32more.Windows.Graphics.Display.IDisplayPropertiesStatics) -> win32more.Windows.Graphics.Display.DisplayOrientations: ...
    @winrt_classmethod
    def put_AutoRotationPreferences(cls: win32more.Windows.Graphics.Display.IDisplayPropertiesStatics, value: win32more.Windows.Graphics.Display.DisplayOrientations) -> Void: ...
    @winrt_classmethod
    def add_OrientationChanged(cls: win32more.Windows.Graphics.Display.IDisplayPropertiesStatics, handler: win32more.Windows.Graphics.Display.DisplayPropertiesEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_OrientationChanged(cls: win32more.Windows.Graphics.Display.IDisplayPropertiesStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_ResolutionScale(cls: win32more.Windows.Graphics.Display.IDisplayPropertiesStatics) -> win32more.Windows.Graphics.Display.ResolutionScale: ...
    @winrt_classmethod
    def get_LogicalDpi(cls: win32more.Windows.Graphics.Display.IDisplayPropertiesStatics) -> Single: ...
    @winrt_classmethod
    def add_LogicalDpiChanged(cls: win32more.Windows.Graphics.Display.IDisplayPropertiesStatics, handler: win32more.Windows.Graphics.Display.DisplayPropertiesEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_LogicalDpiChanged(cls: win32more.Windows.Graphics.Display.IDisplayPropertiesStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_StereoEnabled(cls: win32more.Windows.Graphics.Display.IDisplayPropertiesStatics) -> Boolean: ...
    @winrt_classmethod
    def add_StereoEnabledChanged(cls: win32more.Windows.Graphics.Display.IDisplayPropertiesStatics, handler: win32more.Windows.Graphics.Display.DisplayPropertiesEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_StereoEnabledChanged(cls: win32more.Windows.Graphics.Display.IDisplayPropertiesStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def GetColorProfileAsync(cls: win32more.Windows.Graphics.Display.IDisplayPropertiesStatics) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.Streams.IRandomAccessStream]: ...
    @winrt_classmethod
    def add_ColorProfileChanged(cls: win32more.Windows.Graphics.Display.IDisplayPropertiesStatics, handler: win32more.Windows.Graphics.Display.DisplayPropertiesEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_ColorProfileChanged(cls: win32more.Windows.Graphics.Display.IDisplayPropertiesStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def add_DisplayContentsInvalidated(cls: win32more.Windows.Graphics.Display.IDisplayPropertiesStatics, handler: win32more.Windows.Graphics.Display.DisplayPropertiesEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_DisplayContentsInvalidated(cls: win32more.Windows.Graphics.Display.IDisplayPropertiesStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    _DisplayProperties_Meta_.AutoRotationPreferences = property(get_AutoRotationPreferences, put_AutoRotationPreferences)
    _DisplayProperties_Meta_.CurrentOrientation = property(get_CurrentOrientation, None)
    _DisplayProperties_Meta_.LogicalDpi = property(get_LogicalDpi, None)
    _DisplayProperties_Meta_.NativeOrientation = property(get_NativeOrientation, None)
    _DisplayProperties_Meta_.ResolutionScale = property(get_ResolutionScale, None)
    _DisplayProperties_Meta_.StereoEnabled = property(get_StereoEnabled, None)
class DisplayPropertiesEventHandler(MulticastDelegate):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{dbdd8b01-f1a1-46d1-9ee3-543bcc995980}')
    @winrt_commethod(3)
    def Invoke(self, sender: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
class DisplayServices(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Display.IDisplayServices
    _classid_ = 'Windows.Graphics.Display.DisplayServices'
    @winrt_classmethod
    def FindAll(cls: win32more.Windows.Graphics.Display.IDisplayServicesStatics) -> ReceiveArray[win32more.Windows.Graphics.DisplayId]: ...
class HdrMetadataFormat(Enum, Int32):
    Hdr10 = 0
    Hdr10Plus = 1
class IAdvancedColorInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Display.IAdvancedColorInfo'
    _iid_ = Guid('{8797dcfb-b229-4081-ae9a-2cc85e34ad6a}')
    @winrt_commethod(6)
    def get_CurrentAdvancedColorKind(self) -> win32more.Windows.Graphics.Display.AdvancedColorKind: ...
    @winrt_commethod(7)
    def get_RedPrimary(self) -> win32more.Windows.Foundation.Point: ...
    @winrt_commethod(8)
    def get_GreenPrimary(self) -> win32more.Windows.Foundation.Point: ...
    @winrt_commethod(9)
    def get_BluePrimary(self) -> win32more.Windows.Foundation.Point: ...
    @winrt_commethod(10)
    def get_WhitePoint(self) -> win32more.Windows.Foundation.Point: ...
    @winrt_commethod(11)
    def get_MaxLuminanceInNits(self) -> Single: ...
    @winrt_commethod(12)
    def get_MinLuminanceInNits(self) -> Single: ...
    @winrt_commethod(13)
    def get_MaxAverageFullFrameLuminanceInNits(self) -> Single: ...
    @winrt_commethod(14)
    def get_SdrWhiteLevelInNits(self) -> Single: ...
    @winrt_commethod(15)
    def IsHdrMetadataFormatCurrentlySupported(self, format: win32more.Windows.Graphics.Display.HdrMetadataFormat) -> Boolean: ...
    @winrt_commethod(16)
    def IsAdvancedColorKindAvailable(self, kind: win32more.Windows.Graphics.Display.AdvancedColorKind) -> Boolean: ...
    BluePrimary = property(get_BluePrimary, None)
    CurrentAdvancedColorKind = property(get_CurrentAdvancedColorKind, None)
    GreenPrimary = property(get_GreenPrimary, None)
    MaxAverageFullFrameLuminanceInNits = property(get_MaxAverageFullFrameLuminanceInNits, None)
    MaxLuminanceInNits = property(get_MaxLuminanceInNits, None)
    MinLuminanceInNits = property(get_MinLuminanceInNits, None)
    RedPrimary = property(get_RedPrimary, None)
    SdrWhiteLevelInNits = property(get_SdrWhiteLevelInNits, None)
    WhitePoint = property(get_WhitePoint, None)
class IBrightnessOverride(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Display.IBrightnessOverride'
    _iid_ = Guid('{96c9621a-c143-4392-bedd-4a7e9574c8fd}')
    @winrt_commethod(6)
    def get_IsSupported(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_IsOverrideActive(self) -> Boolean: ...
    @winrt_commethod(8)
    def get_BrightnessLevel(self) -> Double: ...
    @winrt_commethod(9)
    def SetBrightnessLevel(self, brightnessLevel: Double, options: win32more.Windows.Graphics.Display.DisplayBrightnessOverrideOptions) -> Void: ...
    @winrt_commethod(10)
    def SetBrightnessScenario(self, scenario: win32more.Windows.Graphics.Display.DisplayBrightnessScenario, options: win32more.Windows.Graphics.Display.DisplayBrightnessOverrideOptions) -> Void: ...
    @winrt_commethod(11)
    def GetLevelForScenario(self, scenario: win32more.Windows.Graphics.Display.DisplayBrightnessScenario) -> Double: ...
    @winrt_commethod(12)
    def StartOverride(self) -> Void: ...
    @winrt_commethod(13)
    def StopOverride(self) -> Void: ...
    @winrt_commethod(14)
    def add_IsSupportedChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Graphics.Display.BrightnessOverride, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(15)
    def remove_IsSupportedChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(16)
    def add_IsOverrideActiveChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Graphics.Display.BrightnessOverride, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(17)
    def remove_IsOverrideActiveChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(18)
    def add_BrightnessLevelChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Graphics.Display.BrightnessOverride, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(19)
    def remove_BrightnessLevelChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    BrightnessLevel = property(get_BrightnessLevel, None)
    IsOverrideActive = property(get_IsOverrideActive, None)
    IsSupported = property(get_IsSupported, None)
    IsSupportedChanged = event()
    IsOverrideActiveChanged = event()
    BrightnessLevelChanged = event()
class IBrightnessOverrideSettings(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Display.IBrightnessOverrideSettings'
    _iid_ = Guid('{d112ab2a-7604-4dba-bcf8-4b6f49502cb0}')
    @winrt_commethod(6)
    def get_DesiredLevel(self) -> Double: ...
    @winrt_commethod(7)
    def get_DesiredNits(self) -> Single: ...
    DesiredLevel = property(get_DesiredLevel, None)
    DesiredNits = property(get_DesiredNits, None)
class IBrightnessOverrideSettingsStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Display.IBrightnessOverrideSettingsStatics'
    _iid_ = Guid('{d487dc90-6f74-440b-b383-5fe96cf00b0f}')
    @winrt_commethod(6)
    def CreateFromLevel(self, level: Double) -> win32more.Windows.Graphics.Display.BrightnessOverrideSettings: ...
    @winrt_commethod(7)
    def CreateFromNits(self, nits: Single) -> win32more.Windows.Graphics.Display.BrightnessOverrideSettings: ...
    @winrt_commethod(8)
    def CreateFromDisplayBrightnessOverrideScenario(self, overrideScenario: win32more.Windows.Graphics.Display.DisplayBrightnessOverrideScenario) -> win32more.Windows.Graphics.Display.BrightnessOverrideSettings: ...
class IBrightnessOverrideStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Display.IBrightnessOverrideStatics'
    _iid_ = Guid('{03a7b9ed-e1f1-4a68-a11f-946ad8ce5393}')
    @winrt_commethod(6)
    def GetDefaultForSystem(self) -> win32more.Windows.Graphics.Display.BrightnessOverride: ...
    @winrt_commethod(7)
    def GetForCurrentView(self) -> win32more.Windows.Graphics.Display.BrightnessOverride: ...
    @winrt_commethod(8)
    def SaveForSystemAsync(self, value: win32more.Windows.Graphics.Display.BrightnessOverride) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
class IColorOverrideSettings(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Display.IColorOverrideSettings'
    _iid_ = Guid('{fbefa134-4a81-4c4d-a5b6-7d1b5c4bd00b}')
    @winrt_commethod(6)
    def get_DesiredDisplayColorOverrideScenario(self) -> win32more.Windows.Graphics.Display.DisplayColorOverrideScenario: ...
    DesiredDisplayColorOverrideScenario = property(get_DesiredDisplayColorOverrideScenario, None)
class IColorOverrideSettingsStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Display.IColorOverrideSettingsStatics'
    _iid_ = Guid('{b068e05f-c41f-4ac9-afab-827ab6248f9a}')
    @winrt_commethod(6)
    def CreateFromDisplayColorOverrideScenario(self, overrideScenario: win32more.Windows.Graphics.Display.DisplayColorOverrideScenario) -> win32more.Windows.Graphics.Display.ColorOverrideSettings: ...
class IDisplayEnhancementOverride(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Display.IDisplayEnhancementOverride'
    _iid_ = Guid('{429594cf-d97a-4b02-a428-5c4292f7f522}')
    @winrt_commethod(6)
    def get_ColorOverrideSettings(self) -> win32more.Windows.Graphics.Display.ColorOverrideSettings: ...
    @winrt_commethod(7)
    def put_ColorOverrideSettings(self, value: win32more.Windows.Graphics.Display.ColorOverrideSettings) -> Void: ...
    @winrt_commethod(8)
    def get_BrightnessOverrideSettings(self) -> win32more.Windows.Graphics.Display.BrightnessOverrideSettings: ...
    @winrt_commethod(9)
    def put_BrightnessOverrideSettings(self, value: win32more.Windows.Graphics.Display.BrightnessOverrideSettings) -> Void: ...
    @winrt_commethod(10)
    def get_CanOverride(self) -> Boolean: ...
    @winrt_commethod(11)
    def get_IsOverrideActive(self) -> Boolean: ...
    @winrt_commethod(12)
    def GetCurrentDisplayEnhancementOverrideCapabilities(self) -> win32more.Windows.Graphics.Display.DisplayEnhancementOverrideCapabilities: ...
    @winrt_commethod(13)
    def RequestOverride(self) -> Void: ...
    @winrt_commethod(14)
    def StopOverride(self) -> Void: ...
    @winrt_commethod(15)
    def add_CanOverrideChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Graphics.Display.DisplayEnhancementOverride, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(16)
    def remove_CanOverrideChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(17)
    def add_IsOverrideActiveChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Graphics.Display.DisplayEnhancementOverride, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(18)
    def remove_IsOverrideActiveChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(19)
    def add_DisplayEnhancementOverrideCapabilitiesChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Graphics.Display.DisplayEnhancementOverride, win32more.Windows.Graphics.Display.DisplayEnhancementOverrideCapabilitiesChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(20)
    def remove_DisplayEnhancementOverrideCapabilitiesChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    BrightnessOverrideSettings = property(get_BrightnessOverrideSettings, put_BrightnessOverrideSettings)
    CanOverride = property(get_CanOverride, None)
    ColorOverrideSettings = property(get_ColorOverrideSettings, put_ColorOverrideSettings)
    IsOverrideActive = property(get_IsOverrideActive, None)
    CanOverrideChanged = event()
    IsOverrideActiveChanged = event()
    DisplayEnhancementOverrideCapabilitiesChanged = event()
class IDisplayEnhancementOverrideCapabilities(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Display.IDisplayEnhancementOverrideCapabilities'
    _iid_ = Guid('{457060de-ee5a-47b7-9918-1e51e812ccc8}')
    @winrt_commethod(6)
    def get_IsBrightnessControlSupported(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_IsBrightnessNitsControlSupported(self) -> Boolean: ...
    @winrt_commethod(8)
    def GetSupportedNitRanges(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Graphics.Display.NitRange]: ...
    IsBrightnessControlSupported = property(get_IsBrightnessControlSupported, None)
    IsBrightnessNitsControlSupported = property(get_IsBrightnessNitsControlSupported, None)
class IDisplayEnhancementOverrideCapabilitiesChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Display.IDisplayEnhancementOverrideCapabilitiesChangedEventArgs'
    _iid_ = Guid('{db61e664-15fa-49da-8b77-07dbd2af585d}')
    @winrt_commethod(6)
    def get_Capabilities(self) -> win32more.Windows.Graphics.Display.DisplayEnhancementOverrideCapabilities: ...
    Capabilities = property(get_Capabilities, None)
class IDisplayEnhancementOverrideStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Display.IDisplayEnhancementOverrideStatics'
    _iid_ = Guid('{cf5b7ec1-9791-4453-b013-29b6f778e519}')
    @winrt_commethod(6)
    def GetForCurrentView(self) -> win32more.Windows.Graphics.Display.DisplayEnhancementOverride: ...
class IDisplayInformation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Display.IDisplayInformation'
    _iid_ = Guid('{bed112ae-adc3-4dc9-ae65-851f4d7d4799}')
    @winrt_commethod(6)
    def get_CurrentOrientation(self) -> win32more.Windows.Graphics.Display.DisplayOrientations: ...
    @winrt_commethod(7)
    def get_NativeOrientation(self) -> win32more.Windows.Graphics.Display.DisplayOrientations: ...
    @winrt_commethod(8)
    def add_OrientationChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Graphics.Display.DisplayInformation, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_OrientationChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(10)
    def get_ResolutionScale(self) -> win32more.Windows.Graphics.Display.ResolutionScale: ...
    @winrt_commethod(11)
    def get_LogicalDpi(self) -> Single: ...
    @winrt_commethod(12)
    def get_RawDpiX(self) -> Single: ...
    @winrt_commethod(13)
    def get_RawDpiY(self) -> Single: ...
    @winrt_commethod(14)
    def add_DpiChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Graphics.Display.DisplayInformation, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(15)
    def remove_DpiChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(16)
    def get_StereoEnabled(self) -> Boolean: ...
    @winrt_commethod(17)
    def add_StereoEnabledChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Graphics.Display.DisplayInformation, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(18)
    def remove_StereoEnabledChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(19)
    def GetColorProfileAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.Streams.IRandomAccessStream]: ...
    @winrt_commethod(20)
    def add_ColorProfileChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Graphics.Display.DisplayInformation, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(21)
    def remove_ColorProfileChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    CurrentOrientation = property(get_CurrentOrientation, None)
    LogicalDpi = property(get_LogicalDpi, None)
    NativeOrientation = property(get_NativeOrientation, None)
    RawDpiX = property(get_RawDpiX, None)
    RawDpiY = property(get_RawDpiY, None)
    ResolutionScale = property(get_ResolutionScale, None)
    StereoEnabled = property(get_StereoEnabled, None)
    OrientationChanged = event()
    DpiChanged = event()
    StereoEnabledChanged = event()
    ColorProfileChanged = event()
class IDisplayInformation2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Display.IDisplayInformation2'
    _iid_ = Guid('{4dcd0021-fad1-4b8e-8edf-775887b8bf19}')
    @winrt_commethod(6)
    def get_RawPixelsPerViewPixel(self) -> Double: ...
    RawPixelsPerViewPixel = property(get_RawPixelsPerViewPixel, None)
class IDisplayInformation3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Display.IDisplayInformation3'
    _iid_ = Guid('{db15011d-0f09-4466-8ff3-11de9a3c929a}')
    @winrt_commethod(6)
    def get_DiagonalSizeInInches(self) -> win32more.Windows.Foundation.IReference[Double]: ...
    DiagonalSizeInInches = property(get_DiagonalSizeInInches, None)
class IDisplayInformation4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Display.IDisplayInformation4'
    _iid_ = Guid('{c972ce2f-1242-46be-b536-e1aafe9e7acf}')
    @winrt_commethod(6)
    def get_ScreenWidthInRawPixels(self) -> UInt32: ...
    @winrt_commethod(7)
    def get_ScreenHeightInRawPixels(self) -> UInt32: ...
    ScreenHeightInRawPixels = property(get_ScreenHeightInRawPixels, None)
    ScreenWidthInRawPixels = property(get_ScreenWidthInRawPixels, None)
class IDisplayInformation5(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Display.IDisplayInformation5'
    _iid_ = Guid('{3a5442dc-2cde-4a8d-80d1-21dc5adcc1aa}')
    @winrt_commethod(6)
    def GetAdvancedColorInfo(self) -> win32more.Windows.Graphics.Display.AdvancedColorInfo: ...
    @winrt_commethod(7)
    def add_AdvancedColorInfoChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Graphics.Display.DisplayInformation, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(8)
    def remove_AdvancedColorInfoChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    AdvancedColorInfoChanged = event()
class IDisplayInformationStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Display.IDisplayInformationStatics'
    _iid_ = Guid('{c6a02a6c-d452-44dc-ba07-96f3c6adf9d1}')
    @winrt_commethod(6)
    def GetForCurrentView(self) -> win32more.Windows.Graphics.Display.DisplayInformation: ...
    @winrt_commethod(7)
    def get_AutoRotationPreferences(self) -> win32more.Windows.Graphics.Display.DisplayOrientations: ...
    @winrt_commethod(8)
    def put_AutoRotationPreferences(self, value: win32more.Windows.Graphics.Display.DisplayOrientations) -> Void: ...
    @winrt_commethod(9)
    def add_DisplayContentsInvalidated(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Graphics.Display.DisplayInformation, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(10)
    def remove_DisplayContentsInvalidated(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    AutoRotationPreferences = property(get_AutoRotationPreferences, put_AutoRotationPreferences)
    DisplayContentsInvalidated = event()
class IDisplayPropertiesStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Display.IDisplayPropertiesStatics'
    _iid_ = Guid('{6937ed8d-30ea-4ded-8271-4553ff02f68a}')
    @winrt_commethod(6)
    def get_CurrentOrientation(self) -> win32more.Windows.Graphics.Display.DisplayOrientations: ...
    @winrt_commethod(7)
    def get_NativeOrientation(self) -> win32more.Windows.Graphics.Display.DisplayOrientations: ...
    @winrt_commethod(8)
    def get_AutoRotationPreferences(self) -> win32more.Windows.Graphics.Display.DisplayOrientations: ...
    @winrt_commethod(9)
    def put_AutoRotationPreferences(self, value: win32more.Windows.Graphics.Display.DisplayOrientations) -> Void: ...
    @winrt_commethod(10)
    def add_OrientationChanged(self, handler: win32more.Windows.Graphics.Display.DisplayPropertiesEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(11)
    def remove_OrientationChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(12)
    def get_ResolutionScale(self) -> win32more.Windows.Graphics.Display.ResolutionScale: ...
    @winrt_commethod(13)
    def get_LogicalDpi(self) -> Single: ...
    @winrt_commethod(14)
    def add_LogicalDpiChanged(self, handler: win32more.Windows.Graphics.Display.DisplayPropertiesEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(15)
    def remove_LogicalDpiChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(16)
    def get_StereoEnabled(self) -> Boolean: ...
    @winrt_commethod(17)
    def add_StereoEnabledChanged(self, handler: win32more.Windows.Graphics.Display.DisplayPropertiesEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(18)
    def remove_StereoEnabledChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(19)
    def GetColorProfileAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.Streams.IRandomAccessStream]: ...
    @winrt_commethod(20)
    def add_ColorProfileChanged(self, handler: win32more.Windows.Graphics.Display.DisplayPropertiesEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(21)
    def remove_ColorProfileChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(22)
    def add_DisplayContentsInvalidated(self, handler: win32more.Windows.Graphics.Display.DisplayPropertiesEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(23)
    def remove_DisplayContentsInvalidated(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    AutoRotationPreferences = property(get_AutoRotationPreferences, put_AutoRotationPreferences)
    CurrentOrientation = property(get_CurrentOrientation, None)
    LogicalDpi = property(get_LogicalDpi, None)
    NativeOrientation = property(get_NativeOrientation, None)
    ResolutionScale = property(get_ResolutionScale, None)
    StereoEnabled = property(get_StereoEnabled, None)
    OrientationChanged = event()
    LogicalDpiChanged = event()
    StereoEnabledChanged = event()
    ColorProfileChanged = event()
    DisplayContentsInvalidated = event()
class IDisplayServices(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Display.IDisplayServices'
    _iid_ = Guid('{1b54f32b-890d-5747-bd26-fdbdeb0c8a71}')
class IDisplayServicesStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Display.IDisplayServicesStatics'
    _iid_ = Guid('{dc2096bf-730a-5560-b461-91c13d692e0c}')
    @winrt_commethod(6)
    def FindAll(self) -> ReceiveArray[win32more.Windows.Graphics.DisplayId]: ...
class NitRange(Structure):
    MinNits: Single
    MaxNits: Single
    StepSizeNits: Single
class ResolutionScale(Enum, Int32):
    Invalid = 0
    Scale100Percent = 100
    Scale120Percent = 120
    Scale125Percent = 125
    Scale140Percent = 140
    Scale150Percent = 150
    Scale160Percent = 160
    Scale175Percent = 175
    Scale180Percent = 180
    Scale200Percent = 200
    Scale225Percent = 225
    Scale250Percent = 250
    Scale300Percent = 300
    Scale350Percent = 350
    Scale400Percent = 400
    Scale450Percent = 450
    Scale500Percent = 500


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Graphics.DXCore
import win32more.Windows.Win32.System.Com
_FACDXCORE: UInt32 = 2176
DXCORE_ADAPTER_ATTRIBUTE_D3D11_GRAPHICS: Guid = Guid('{8c47866b-7583-450d-f0f0-6bada895af4b}')
DXCORE_ADAPTER_ATTRIBUTE_D3D12_GRAPHICS: Guid = Guid('{0c9ece4d-2f6e-4f01-8c96-e89e331b47b1}')
DXCORE_ADAPTER_ATTRIBUTE_D3D12_CORE_COMPUTE: Guid = Guid('{248e2800-a793-4724-abaa-23a6de1be090}')
@winfunctype('DXCORE.dll')
def DXCoreCreateAdapterFactory(riid: POINTER(Guid), ppvFactory: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class DXCoreAdapterMemoryBudget(Structure):
    budget: UInt64
    currentUsage: UInt64
    availableForReservation: UInt64
    currentReservation: UInt64
class DXCoreAdapterMemoryBudgetNodeSegmentGroup(Structure):
    nodeIndex: UInt32
    segmentGroup: win32more.Windows.Win32.Graphics.DXCore.DXCoreSegmentGroup
DXCoreAdapterPreference = UInt32
Hardware: win32more.Windows.Win32.Graphics.DXCore.DXCoreAdapterPreference = 0
MinimumPower: win32more.Windows.Win32.Graphics.DXCore.DXCoreAdapterPreference = 1
HighPerformance: win32more.Windows.Win32.Graphics.DXCore.DXCoreAdapterPreference = 2
DXCoreAdapterProperty = UInt32
InstanceLuid: win32more.Windows.Win32.Graphics.DXCore.DXCoreAdapterProperty = 0
DriverVersion: win32more.Windows.Win32.Graphics.DXCore.DXCoreAdapterProperty = 1
DriverDescription: win32more.Windows.Win32.Graphics.DXCore.DXCoreAdapterProperty = 2
HardwareID: win32more.Windows.Win32.Graphics.DXCore.DXCoreAdapterProperty = 3
KmdModelVersion: win32more.Windows.Win32.Graphics.DXCore.DXCoreAdapterProperty = 4
ComputePreemptionGranularity: win32more.Windows.Win32.Graphics.DXCore.DXCoreAdapterProperty = 5
GraphicsPreemptionGranularity: win32more.Windows.Win32.Graphics.DXCore.DXCoreAdapterProperty = 6
DedicatedAdapterMemory: win32more.Windows.Win32.Graphics.DXCore.DXCoreAdapterProperty = 7
DedicatedSystemMemory: win32more.Windows.Win32.Graphics.DXCore.DXCoreAdapterProperty = 8
SharedSystemMemory: win32more.Windows.Win32.Graphics.DXCore.DXCoreAdapterProperty = 9
AcgCompatible: win32more.Windows.Win32.Graphics.DXCore.DXCoreAdapterProperty = 10
IsHardware: win32more.Windows.Win32.Graphics.DXCore.DXCoreAdapterProperty = 11
IsIntegrated: win32more.Windows.Win32.Graphics.DXCore.DXCoreAdapterProperty = 12
IsDetachable: win32more.Windows.Win32.Graphics.DXCore.DXCoreAdapterProperty = 13
HardwareIDParts: win32more.Windows.Win32.Graphics.DXCore.DXCoreAdapterProperty = 14
DXCoreAdapterState = UInt32
IsDriverUpdateInProgress: win32more.Windows.Win32.Graphics.DXCore.DXCoreAdapterState = 0
AdapterMemoryBudget: win32more.Windows.Win32.Graphics.DXCore.DXCoreAdapterState = 1
class DXCoreHardwareID(Structure):
    vendorID: UInt32
    deviceID: UInt32
    subSysID: UInt32
    revision: UInt32
class DXCoreHardwareIDParts(Structure):
    vendorID: UInt32
    deviceID: UInt32
    subSystemID: UInt32
    subVendorID: UInt32
    revisionID: UInt32
DXCoreNotificationType = UInt32
AdapterListStale: win32more.Windows.Win32.Graphics.DXCore.DXCoreNotificationType = 0
AdapterNoLongerValid: win32more.Windows.Win32.Graphics.DXCore.DXCoreNotificationType = 1
AdapterBudgetChange: win32more.Windows.Win32.Graphics.DXCore.DXCoreNotificationType = 2
AdapterHardwareContentProtectionTeardown: win32more.Windows.Win32.Graphics.DXCore.DXCoreNotificationType = 3
DXCoreSegmentGroup = UInt32
Local: win32more.Windows.Win32.Graphics.DXCore.DXCoreSegmentGroup = 0
NonLocal: win32more.Windows.Win32.Graphics.DXCore.DXCoreSegmentGroup = 1
class IDXCoreAdapter(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{f0db4c7f-fe5a-42a2-bd62-f2a6cf6fc83e}')
    @commethod(3)
    def IsValid(self) -> Boolean: ...
    @commethod(4)
    def IsAttributeSupported(self, attributeGUID: POINTER(Guid)) -> Boolean: ...
    @commethod(5)
    def IsPropertySupported(self, property: win32more.Windows.Win32.Graphics.DXCore.DXCoreAdapterProperty) -> Boolean: ...
    @commethod(6)
    def GetProperty(self, property: win32more.Windows.Win32.Graphics.DXCore.DXCoreAdapterProperty, bufferSize: UIntPtr, propertyData: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetPropertySize(self, property: win32more.Windows.Win32.Graphics.DXCore.DXCoreAdapterProperty, bufferSize: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def IsQueryStateSupported(self, property: win32more.Windows.Win32.Graphics.DXCore.DXCoreAdapterState) -> Boolean: ...
    @commethod(9)
    def QueryState(self, state: win32more.Windows.Win32.Graphics.DXCore.DXCoreAdapterState, inputStateDetailsSize: UIntPtr, inputStateDetails: VoidPtr, outputBufferSize: UIntPtr, outputBuffer: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def IsSetStateSupported(self, property: win32more.Windows.Win32.Graphics.DXCore.DXCoreAdapterState) -> Boolean: ...
    @commethod(11)
    def SetState(self, state: win32more.Windows.Win32.Graphics.DXCore.DXCoreAdapterState, inputStateDetailsSize: UIntPtr, inputStateDetails: VoidPtr, inputDataSize: UIntPtr, inputData: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetFactory(self, riid: POINTER(Guid), ppvFactory: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDXCoreAdapterFactory(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{78ee5945-c36e-4b13-a669-005dd11c0f06}')
    @commethod(3)
    def CreateAdapterList(self, numAttributes: UInt32, filterAttributes: POINTER(Guid), riid: POINTER(Guid), ppvAdapterList: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetAdapterByLuid(self, adapterLUID: POINTER(win32more.Windows.Win32.Foundation.LUID), riid: POINTER(Guid), ppvAdapter: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def IsNotificationTypeSupported(self, notificationType: win32more.Windows.Win32.Graphics.DXCore.DXCoreNotificationType) -> Boolean: ...
    @commethod(6)
    def RegisterEventNotification(self, dxCoreObject: win32more.Windows.Win32.System.Com.IUnknown, notificationType: win32more.Windows.Win32.Graphics.DXCore.DXCoreNotificationType, callbackFunction: win32more.Windows.Win32.Graphics.DXCore.PFN_DXCORE_NOTIFICATION_CALLBACK, callbackContext: VoidPtr, eventCookie: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def UnregisterEventNotification(self, eventCookie: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDXCoreAdapterList(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{526c7776-40e9-459b-b711-f32ad76dfc28}')
    @commethod(3)
    def GetAdapter(self, index: UInt32, riid: POINTER(Guid), ppvAdapter: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetAdapterCount(self) -> UInt32: ...
    @commethod(5)
    def IsStale(self) -> Boolean: ...
    @commethod(6)
    def GetFactory(self, riid: POINTER(Guid), ppvFactory: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def Sort(self, numPreferences: UInt32, preferences: POINTER(win32more.Windows.Win32.Graphics.DXCore.DXCoreAdapterPreference)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def IsAdapterPreferenceSupported(self, preference: win32more.Windows.Win32.Graphics.DXCore.DXCoreAdapterPreference) -> Boolean: ...
@winfunctype_pointer
def PFN_DXCORE_NOTIFICATION_CALLBACK(notificationType: win32more.Windows.Win32.Graphics.DXCore.DXCoreNotificationType, object: win32more.Windows.Win32.System.Com.IUnknown, context: VoidPtr) -> Void: ...


make_ready(__name__)
